<?php
/*
 * Plugin Name: WP Accounts
 * Version: 1.4.1
 * Plugin URI: https://webd.uk/wp-accounts/
 * Description: Manage your Clients, Invoices, Receipts and Payments. Send Invoices and Receipts to clients via email.
 * Author: webd.uk
 * Author URI: https://webd.uk
 * Text Domain: wp-accounts
 */



if (!defined('ABSPATH')) {
    exit('This isn\'t the page you\'re looking for. Move along, move along.');
}



if (!class_exists('wpaccounts_class')) {

	class wpaccounts_class {

		function __construct() {

            register_activation_hook(__FILE__, array($this, 'wpa_install'));
            register_activation_hook(__FILE__, array($this, 'wpa_install_data'));
			add_action('admin_init', array($this, 'wpa_register_script'));
            add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'wpa_add_plugin_settings_link'));
			add_action('wp_before_admin_bar_render', array($this, 'wpa_admin_bar_render'));
			add_action('admin_menu', array($this, 'wpa_menu'));
            add_action('wp_ajax_wpa_get_attachment_url', array($this, 'wpa_ajax_get_attachment_url'));

		}

		function wpa_add_plugin_settings_link($links) {

			$settings_link = '<a href="' . $this->wpa_home_root() . 'wp-admin/admin.php?page=manage-settings" title="' . __('Settings', 'wp-accounts') . '">' . __('Settings', 'wp-accounts') . '</a>';
			array_unshift( $links, $settings_link );
			return $links;

		}



function wpa_register_script() {

    wp_register_script('wpa-settings-pickers', plugins_url('js/settings-pickers.js', __FILE__), array('wp-color-picker'), false, true );
    wp_register_style('jquery-ui', 'https://code.jquery.com/ui/1.11.2/themes/smoothness/jquery-ui.css');
    wp_register_script('wpa-date-pickers', plugins_url('js/date-pickers.js', __FILE__), array('jquery-ui-datepicker'), false, true );

}

function wpa_install() {
    global $wpdb;
    
    $charset_collate = $wpdb->get_charset_collate();
    $sqls=array(

"CREATE TABLE " . $wpdb->prefix . "accounts_invoice_status (
ID int(11) NOT NULL AUTO_INCREMENT,
status varchar(9) NOT NULL,
PRIMARY KEY  (ID)
) $charset_collate AUTO_INCREMENT=1;",

"CREATE TABLE " . $wpdb->prefix . "accounts_payment_methods (
ID int(11) NOT NULL AUTO_INCREMENT,
payment_method varchar(12) NOT NULL,
PRIMARY KEY  (ID)
) $charset_collate AUTO_INCREMENT=1;",

"CREATE TABLE " . $wpdb->prefix . "accounts_clients (
ID int(11) NOT NULL AUTO_INCREMENT,
company varchar(255) DEFAULT NULL,
address1 varchar(255) NOT NULL,
address2 varchar(255) DEFAULT NULL,
address3 varchar(255) DEFAULT NULL,
town varchar(255) NOT NULL,
county varchar(255) DEFAULT NULL,
postcode varchar(13) NOT NULL,
contact varchar(255) NOT NULL,
telephone varchar(20) DEFAULT NULL,
mobile varchar(20) DEFAULT NULL,
email varchar(255) DEFAULT NULL,
notes text DEFAULT NULL,
PRIMARY KEY  (ID),
KEY company (company)
) $charset_collate AUTO_INCREMENT=1;",

"CREATE TABLE " . $wpdb->prefix . "accounts_invoices (
ID int(11) NOT NULL AUTO_INCREMENT,
client int(11) NOT NULL,
invoice_date date NOT NULL,
monthly tinyint(1) NOT NULL DEFAULT '0',
yearly tinyint(1) NOT NULL DEFAULT '0',
item1 varchar(255) NOT NULL,
price1 decimal(10,2) NOT NULL,
item2 varchar(255) DEFAULT NULL,
price2 decimal(10,2) DEFAULT NULL,
item3 varchar(255) DEFAULT NULL,
price3 decimal(10,2) DEFAULT NULL,
item4 varchar(255) DEFAULT NULL,
price4 decimal(10,2) DEFAULT NULL,
item5 varchar(255) DEFAULT NULL,
price5 decimal(10,2) DEFAULT NULL,
invoice_status int(11) NOT NULL DEFAULT '1',
date_paid date DEFAULT NULL,
payment_method int(11) DEFAULT NULL,
mileage int(11) DEFAULT '0',
notes text DEFAULT NULL,
PRIMARY KEY  (ID),
KEY client (client),
KEY payment_method (payment_method),
KEY invoice_status (invoice_status)
) $charset_collate AUTO_INCREMENT=1;",

"CREATE TABLE " . $wpdb->prefix . "accounts_payments (
ID int(11) NOT NULL AUTO_INCREMENT,
supplier varchar(255) NOT NULL,
invoice_date date NOT NULL,
amount decimal(10,2) NOT NULL,
reference varchar(255) DEFAULT NULL,
expense_type int(11) NOT NULL,
date_paid date NOT NULL,
payment_method int(11) NOT NULL,
mileage int(11) DEFAULT '0',
notes text DEFAULT NULL,
PRIMARY KEY  (ID)
) $charset_collate AUTO_INCREMENT=1;",

"CREATE TABLE " . $wpdb->prefix . "accounts_expense_types (
ID int(11) NOT NULL AUTO_INCREMENT,
expense_type varchar(255) NOT NULL,
PRIMARY KEY  (ID)
) $charset_collate AUTO_INCREMENT=1;");

    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
    foreach ($sqls AS $sql) {
        dbDelta($sql);
    }

	$options = get_option('wp_accounts_options');

    if (!isset($options['email_footer'])) {

        $options['email_footer'] = "<strong>WP Accounts</strong>
We use Wordpress plugin <strong>WP Accounts</strong> to send invoices and receipts. This free Wordpress plugin can be <a href=\"https://wordpress.org/plugins/wp-accounts/\">downloaded from the Wordpress Plugins repository</a>.";
        update_option('wp_accounts_options', $options);

    }

}

function wpa_install_data() {
   global $wpdb;

   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_payment_methods', array('ID' => 1, 'payment_method' => 'Paypal'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_payment_methods', array('ID' => 2, 'payment_method' => 'BACS'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_payment_methods', array('ID' => 3, 'payment_method' => 'Cheque'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_payment_methods', array('ID' => 4, 'payment_method' => 'Cash'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_payment_methods', array('ID' => 5, 'payment_method' => 'Credit Card'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_payment_methods', array('ID' => 6, 'payment_method' => 'Debit Card'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_payment_methods', array('ID' => 7, 'payment_method' => 'Direct Debit'));

   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_invoice_status', array('ID' => 1, 'status' => 'Unpaid'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_invoice_status', array('ID' => 2, 'status' => 'Paid'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_invoice_status', array('ID' => 3, 'status' => 'Cancelled'));

   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 1, 'expense_type' => 'Capital'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 2, 'expense_type' => 'Accounting'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 3, 'expense_type' => 'Director\'s Loan'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 4, 'expense_type' => 'Telephone'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 5, 'expense_type' => 'Web Servers and Domain Names'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 6, 'expense_type' => 'Sub-Contract Work'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 7, 'expense_type' => 'Supplies'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 8, 'expense_type' => 'Advertising and Marketing'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 9, 'expense_type' => 'Sundries'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 10, 'expense_type' => 'Printing, Postage and Stationery'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 11, 'expense_type' => 'Bounced Cheques'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 12, 'expense_type' => 'Wages'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 13, 'expense_type' => 'Dividends'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 14, 'expense_type' => 'Subscriptions'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 15, 'expense_type' => 'Repairs and Renewals'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 16, 'expense_type' => 'Business Trip Expenses'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 17, 'expense_type' => 'HMRC'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 18, 'expense_type' => 'Entertaining'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 19, 'expense_type' => 'Insurance'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 20, 'expense_type' => 'Legal and Professional'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 21, 'expense_type' => 'Vehicle Running'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 22, 'expense_type' => 'Purchases'));
   $rows_affected = $wpdb->insert( $wpdb->prefix . 'accounts_expense_types', array('ID' => 23, 'expense_type' => 'Bank / eBay / Paypal Charges'));

}

function wpa_admin_bar_render() {
    global $wp_admin_bar;
    $wp_admin_bar->add_menu( array(
        'parent' => 'new-content',
        'id' => 'new_client',
        'title' => 'Client',
        'href' => admin_url( 'admin.php?page=manage-clients&edit=true')
    ) );
    $wp_admin_bar->add_menu( array(
        'parent' => 'new-content',
        'id' => 'new_invoice',
        'title' => 'Invoice',
        'href' => admin_url( 'admin.php?page=manage-invoices&edit=true')
    ) );
    $wp_admin_bar->add_menu( array(
        'parent' => 'new-content',
        'id' => 'new_payment',
        'title' => 'Payment',
        'href' => admin_url( 'admin.php?page=manage-payments&amp;edit=true')
    ) );
}

function wpa_menu() {
    if (is_admin()) {
        add_menu_page('WP Accounts Settings', 'WP Accounts', 'manage_options', 'manage-settings', array($this,'wpa_accounts_settings_page'), plugins_url('/images/wp-accounts.png', __FILE__));
        $page = add_submenu_page( 'manage-settings', 'WP Accounts Settings', 'Settings', 'manage_options', 'manage-settings', array($this,'wpa_accounts_settings_page'), plugins_url('/images/wp-accounts.png', __FILE__));
		add_action('admin_print_scripts-' . $page, array($this, 'wpa_enqueue_settings_script'));
        $page = add_submenu_page( 'manage-settings', 'Manage Invoices', 'Manage Invoices', 'manage_options', 'manage-invoices', array($this, 'wpa_manage_invoices_options'));
		add_action('admin_print_scripts-' . $page, array($this, 'wpa_enqueue_date_picker'));
        $page = add_submenu_page( 'manage-settings', 'Manage Receipts', 'Manage Receipts', 'manage_options', 'manage-receipts', array($this, 'wpa_manage_receipts_options'));
		add_action('admin_print_scripts-' . $page, array($this, 'wpa_enqueue_date_picker'));
	    add_submenu_page( 'manage-settings', 'Manage Clients', 'Manage Clients', 'manage_options', 'manage-clients', array($this, 'wpa_manage_clients_options'));
	    add_submenu_page( null, 'Client Statement', 'Client Statement', 'manage_options', 'client-statement', array($this, 'wpa_client_statement_options'));
        $page = add_submenu_page( 'manage-settings', 'Manage Payments', 'Manage Payments', 'manage_options', 'manage-payments', array($this, 'wpa_manage_payments_options'));
		add_action('admin_print_scripts-' . $page, array($this, 'wpa_enqueue_date_picker'));
	    add_submenu_page( 'manage-settings', 'Export CSV', 'Export CSV', 'manage_options', 'export-csv', array($this, 'wpa_export_csv_options'));
	    add_action('admin_init', array($this, 'wpa_register_accounts_settings'));
    }
}

function wpa_register_accounts_settings() {
	register_setting( 'wp_accounts_options', 'wp_accounts_options', array($this, 'wpa_options_validate'));
	add_settings_section('wp_accounts_company_details', 'Company Details', array($this, 'wpa_company_text'), 'wp_accounts');
	add_settings_field('company_name', 'Company Name', array($this, 'wpa_company_name_string'), 'wp_accounts', 'wp_accounts_company_details');
	add_settings_field('company_logo', 'Company Logo', array($this, 'wpa_company_logo_id'), 'wp_accounts', 'wp_accounts_company_details');
	add_settings_field('company_address', 'Company Address', array($this, 'wpa_company_address_string'), 'wp_accounts', 'wp_accounts_company_details');
	add_settings_field('company_telephone', 'Company Telephone', array($this, 'wpa_company_telephone_string'), 'wp_accounts', 'wp_accounts_company_details');
	add_settings_field('accounting_period_start', 'Accounting Period Start', array($this, 'wpa_accounting_period_start_string'), 'wp_accounts', 'wp_accounts_company_details');
	add_settings_field('mileage', 'Enable Mileage', array($this, 'wpa_mileage_string'), 'wp_accounts', 'wp_accounts_company_details');
	add_settings_section('wp_accounts_account', 'Bank Account', array($this, 'wpa_account_text'), 'wp_accounts');
	add_settings_field('sort_code', 'Sort Code', array($this, 'wpa_sort_code_string'), 'wp_accounts', 'wp_accounts_account');
	add_settings_field('account_number', 'Account Number', array($this, 'wpa_account_number_string'), 'wp_accounts', 'wp_accounts_account');
	add_settings_field('cheques', 'Enable Cheques', array($this, 'wpa_cheques_string'), 'wp_accounts', 'wp_accounts_account');
	add_settings_field('paypal', 'Enable Paypal ('.get_bloginfo('admin_email').')', array($this, 'wpa_paypal_string'), 'wp_accounts', 'wp_accounts_account');
	add_settings_field('recurrent', 'Enable Recurrent Invoices', array($this, 'wpa_recurrent_string'), 'wp_accounts', 'wp_accounts_account');
	add_settings_section('wp_accounts_style', 'Email Style', array($this, 'wpa_style_text'), 'wp_accounts');
	add_settings_field('email_color', 'Email Color', array($this, 'wpa_email_color_string'), 'wp_accounts', 'wp_accounts_style');
	add_settings_field('link_color', 'Link Color', array($this, 'wpa_link_color_string'), 'wp_accounts', 'wp_accounts_style');
	add_settings_field('hover_color', 'Hover Color', array($this, 'wpa_hover_color_string'), 'wp_accounts', 'wp_accounts_style');
	add_settings_field('email_font', 'Email Font', array($this, 'wpa_email_font_string'), 'wp_accounts', 'wp_accounts_style');
	add_settings_field('email_footer', 'Email Footer', array($this, 'wpa_email_footer_string'), 'wp_accounts', 'wp_accounts_style');
	add_settings_field('company_google_place_id', 'Company Google Place ID', array($this, 'wpa_company_google_place_id_string'), 'wp_accounts', 'wp_accounts_style');
	add_settings_field('email_advert', 'Email Advert', array($this, 'wpa_email_advert_id'), 'wp_accounts', 'wp_accounts_style');
}

function wpa_company_text() {
	echo '<p>Enter company details below.</p>';
}

function wpa_account_text() {
	echo '<p>Enter bank account details below for BACS payments.</p>';
}

function wpa_style_text() {

	if (isset($_GET['activate']) && $_GET['activate'] == 'true') {
		$this->wpa_activate();
	}

?>

<?php
	if (get_option('wp_accounts_purchased') != true) {
?>

<p><a href="https://www.paypal.com/cgi-bin/webscr?cmd=_xclick&business=info@domainsupport.co.uk&item_name=WP+Accounts+for+<?php echo (isset($_SERVER['HTTPS']) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST']; ?>&amount=30%2E00&currency_code=GBP" title="Upgrade WP Accounts">Upgrade now for &pound;30 to activate email styling</a>.</p>

<p><a href="?page=export-csv&amp;activate=true" title="Activate WP Accounts Upgrade">Activate WP Accounts Upgrade</a>.</p>

<?php
	}
?>

<p><strong>Upgrade Status:</strong> <?php if (get_option('wp_accounts_purchased') == true) { echo('Upgraded'); } else { echo('Not Upgraded'); } ?></p>

<?php
	echo '<p>Use these settings to style the invoice emails.</p>';
}

function wpa_company_name_string() {
	$options = get_option('wp_accounts_options');
	echo "<input id='company_name' name='wp_accounts_options[company_name]' size='40' type='text' value='" . ((isset($options['company_name'])) ? esc_html($options['company_name']) : '') . "' />";
}

function wpa_company_logo_id() {
	$options = get_option('wp_accounts_options');

        if (isset($options['company_logo']) && absint($options['company_logo']) > 0) {

            echo '<img id="company_logo_preview_image" src="' . wp_get_attachment_url($options['company_logo']) . '" />';

        } else {

            echo '<img id="company_logo_preview_image" />';

        }
?>

<br />
<input id="company_logo" name="wp_accounts_options[company_logo]" type="hidden" value="<?php if (isset($options['company_logo'])) { echo esc_html($options['company_logo']); } ?>"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />
<input type="button" class="button-primary" value="<?php esc_attr_e('Select Logo', 'wp-accounts' ); ?>" id="company_logo_media_manager" data-button="<?= wp_create_nonce('wpaccounts'); ?>"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />
<input type="button" value="<?php esc_attr_e('Clear', 'wp-accounts' ); ?>"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> onclick="jQuery('input#company_logo').removeAttr('value'); jQuery('img#company_logo_preview_image').removeAttr('src').replaceWith(jQuery('img#company_logo_preview_image').clone());" />

<?php
}

function wpa_company_address_string() {
	$options = get_option('wp_accounts_options');
	echo "<input id='company_address' name='wp_accounts_options[company_address]' size='40' type='text' value='" . ((isset($options['company_address'])) ? esc_html($options['company_address']) : '') . "' />";
}

function wpa_company_telephone_string() {
	$options = get_option('wp_accounts_options');
	echo "<input id='company_telephone' name='wp_accounts_options[company_telephone]' size='40' type='text' value='" . ((isset($options['company_telephone'])) ? ($this->wpa_format_telephone($this->wpa_clean_telephone($options['company_telephone']))) : '') . "' />";
}

function wpa_accounting_period_start_string() {
	$options = get_option('wp_accounts_options');
	echo "<input id='accounting_period_start' name='wp_accounts_options[accounting_period_start]' size='40' type='text' value='" . ((isset($options['accounting_period_start'])) ? ($options['accounting_period_start']) : '') . "' /> MM-DD";
}

function wpa_mileage_string() {
	$options = get_option('wp_accounts_options');
?>

<input id="mileage" name="wp_accounts_options[mileage]" type="checkbox" value="true"<?php if (isset($options['mileage']) && $options['mileage'] == 'true') { ?> checked="checked"<?php } ?>>

<?php
}

function wpa_sort_code_string() {
	$options = get_option('wp_accounts_options');
	echo "<input id='sort_code' name='wp_accounts_options[sort_code]' size='40' type='text' value='" . ((isset($options['sort_code'])) ? esc_html($options['sort_code']) : '') . "' />";
}

function wpa_account_number_string() {
	$options = get_option('wp_accounts_options');
	echo "<input id='account_number' name='wp_accounts_options[account_number]' size='40' type='text' value='" . ((isset($options['account_number'])) ? esc_html($options['account_number']) : '') . "' />";
}

function wpa_cheques_string() {
	$options = get_option('wp_accounts_options');
?>

<input id="cheques" name="wp_accounts_options[cheques]" type="checkbox" value="true"<?php if (isset($options['cheques']) && $options['cheques']=='true') { ?> checked="checked"<?php } ?>>

<?php
}

function wpa_paypal_string() {
	$options = get_option('wp_accounts_options');
?>

<input id="paypal" name="wp_accounts_options[paypal]" type="checkbox" value="true"<?php if (isset($options['paypal']) && $options['paypal']=='true') { ?> checked="checked"<?php } ?>>

<?php
}

function wpa_recurrent_string() {
	$options = get_option('wp_accounts_options');
?>

<input id="recurrent" name="wp_accounts_options[recurrent]" type="checkbox" value="true"<?php if (isset($options['recurrent']) && $options['recurrent']=='true') { ?> checked="checked"<?php } ?>>

<?php
}

function wpa_email_color_string() {
	$options = get_option('wp_accounts_options');
?>

<input id="email_color"<?php if (get_option('wp_accounts_purchased') == true) { echo(' class="wpa-email-color"'); } ?> name="wp_accounts_options[email_color]" size="40" type="text" value="<?php if (isset($options['email_color'])) { echo esc_html($options['email_color']); } ?>"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />

<?php
}

function wpa_link_color_string() {
	$options = get_option('wp_accounts_options');
?>

<input id="link_color"<?php if (get_option('wp_accounts_purchased') == true) { echo(' class="wpa-link-color"'); } ?> name="wp_accounts_options[link_color]" size="40" type="text" value="<?php if (isset($options['link_color'])) { echo esc_html($options['link_color']); } ?>"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />

<?php
}

function wpa_hover_color_string() {
	$options = get_option('wp_accounts_options');
?>

<input id="hover_color"<?php if (get_option('wp_accounts_purchased') == true) { echo(' class="wpa-hover-color"'); } ?> name="wp_accounts_options[hover_color]" size="40" type="text" value="<?php if (isset($options['hover_color'])) { echo esc_html($options['hover_color']); } ?>"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />

<?php
}

function wpa_email_font_string() {
	$options = get_option('wp_accounts_options');
?>

<p style="font-family: Arial, Helvetica, sans-serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="Arial, Helvetica, sans-serif"<?php if (isset($options['email_font']) && $options['email_font'] == "Arial, Helvetica, sans-serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> /> Arial / Helvetica</p>

<p style="font-family: 'Arial Black', Gadget, sans-serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="'Arial Black', Gadget, sans-serif"<?php if (isset($options['email_font']) && $options['email_font'] == "'Arial Black', Gadget, sans-serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Arial Black / Gadget</p>

<p style="font-family: 'Bookman Old Style', serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="'Bookman Old Style', serif"<?php if (isset($options['email_font']) && $options['email_font'] == "'Bookman Old Style', serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Bookman Old Style</p>

<p style="font-family: 'Comic Sans MS', cursive;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="'Comic Sans MS', cursive"<?php if (isset($options['email_font']) && $options['email_font'] == "'Comic Sans MS', cursive") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Comic Sans MS</p>

<p style="font-family: 'Courier New', Courier, monospace;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="'Courier New', Courier, monospace"<?php if (isset($options['email_font']) && $options['email_font'] == "'Courier New', Courier, monospace") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Courier New / Courier</p>

<p style="font-family: Garamond, serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="Garamond, serif"<?php if (isset($options['email_font']) && $options['email_font'] == "Garamond, serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Garamond</p>

<p style="font-family: Georgia, serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="Georgia, serif"<?php if (isset($options['email_font']) && $options['email_font'] == "Georgia, serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Georgia</p>

<p style="font-family: Impact, Charcoal, sans-serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="Impact, Charcoal, sans-serif"<?php if (isset($options['email_font']) && $options['email_font'] == "Impact, Charcoal, sans-serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Impact / Charcoal</p>

<p style="font-family: 'Lucida Console', Monaco, monospace;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="'Lucida Console', Monaco, monospace"<?php if (isset($options['email_font']) && $options['email_font'] == "'Lucida Console', Monaco, monospace") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Lucida Console / Monaco</p>

<p style="font-family: 'Lucida Sans Unicode', 'Lucida Grande', sans-serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="'Lucida Sans Unicode', 'Lucida Grande', sans-serif"<?php if (isset($options['email_font']) && $options['email_font'] == "'Lucida Sans Unicode', 'Lucida Grande', sans-serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Lucida Sans Unicode / Lucida Grande</p>

<p style="font-family: 'MS Sans Serif', Geneva, sans-serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="'MS Sans Serif', Geneva, sans-serif"<?php if (isset($options['email_font']) && $options['email_font'] == "'MS Sans Serif', Geneva, sans-serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />MS Sans Serif / Geneva</p>

<p style="font-family: 'MS Serif', 'New York', sans-serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="'MS Serif', 'New York', sans-serif"<?php if (isset($options['email_font']) && $options['email_font'] == "'MS Serif', 'New York', sans-serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />MS Serif / New York</p>

<p style="font-family: 'Palatino Linotype', 'Book Antiqua', Palatino, serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="'Palatino Linotype', 'Book Antiqua', Palatino, serif"<?php if (isset($options['email_font']) && $options['email_font'] == "'Palatino Linotype', 'Book Antiqua', Palatino, serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Palatino Linotype / Book Antiqua / Palatino</p>

<p style="font-family: Tahoma, Geneva, sans-serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="Tahoma, Geneva, sans-serif"<?php if (isset($options['email_font']) && $options['email_font'] == "Tahoma, Geneva, sans-serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Tahoma / Geneva</p>

<p style="font-family: 'Times New Roman', Times, serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="'Times New Roman', Times, serif"<?php if (isset($options['email_font']) && $options['email_font'] == "'Times New Roman', Times, serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Times New Roman / Times</p>

<p style="font-family: 'Trebuchet MS', Helvetica, sans-serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="'Trebuchet MS', Helvetica, sans-serif"<?php if (isset($options['email_font']) && $options['email_font'] == "'Trebuchet MS', Helvetica, sans-serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Trebuchet MS / Helvetica</p>

<p style="font-family: Verdana, Geneva, sans-serif;"><input type="radio" name="wp_accounts_options[email_font]" id="email_font_arial" value="Verdana, Geneva, sans-serif"<?php if (isset($options['email_font']) && $options['email_font'] == "Verdana, Geneva, sans-serif") { echo(' checked'); } ?><?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />Verdana / Geneva</p>

<?php
}

function wpa_email_footer_string() {
	$options = get_option('wp_accounts_options');

    if (get_option('wp_accounts_purchased') != true) {

?>

<textarea name="wp_accounts_options[email_footer]" disabled><?php if (isset($options['email_footer'])) { echo(wp_strip_all_tags($options['email_footer'])); } ?></textarea>

<?php

    } else {

        if (isset($options['email_footer'])) { $email_footer = $options['email_footer']; } else { $email_footer = ''; }
        echo wp_editor($email_footer, 'email_footer', array('textarea_name' => 'wp_accounts_options[email_footer]', 'media_buttons' => false));
    
    }

}

function wpa_company_google_place_id_string() {
	$options = get_option('wp_accounts_options');
	echo "<input id='company_google_place_id' name='wp_accounts_options[company_google_place_id]' size='40' type='text' value='" . ((isset($options['company_google_place_id'])) ? esc_html($options['company_google_place_id']) : '') . "'" . ((!get_option('wp_accounts_purchased')) ? ' disabled' : '') . " />";
?>

<br />To invite customers to review your business, locate the <a href="https://developers.google.com/places/place-id#find-id" title="Find your Google Place ID">Google Place ID for your company</a> (you'll need a verified <a href="https://www.google.co.uk/intl/en/business/" title="Google My Business">Google My Business</a> listing).

<?php
}

function wpa_email_advert_id() {
	$options = get_option('wp_accounts_options');

        if (isset($options['email_advert']) && absint($options['email_advert']) > 0) {

            echo '<img id="email_advert_preview_image" src="' . wp_get_attachment_url($options['email_advert']) . '" />';

        } else {

            echo '<img id="email_advert_preview_image" />';

        }
?>

<br />
<input id="email_advert" name="wp_accounts_options[email_advert]" type="hidden" value="<?php if (isset($options['email_advert'])) { echo esc_html($options['email_advert']); } ?>"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />
<input type="button" class="button-primary" value="<?php esc_attr_e('Select Advert', 'wp-accounts' ); ?>" id="email_advert_media_manager" data-button="<?= wp_create_nonce('wpaccounts'); ?>"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> />
<input type="button" value="<?php esc_attr_e('Clear', 'wp-accounts' ); ?>"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> onclick="jQuery('input#email_advert').removeAttr('value'); jQuery('img#email_advert_preview_image').removeAttr('src').replaceWith(jQuery('img#email_advert_preview_image').clone());" />

<?php
}

function wpa_options_validate($input) {

	$options = get_option('wp_accounts_options');
	$options['company_name'] = sanitize_text_field($input['company_name']);
	$options['company_address'] = sanitize_text_field($input['company_address']);
	$options['company_telephone'] = $this->wpa_clean_telephone($input['company_telephone']);
	$options['accounting_period_start'] = sanitize_text_field($input['accounting_period_start']);
	if (isset($input['mileage']) && $input['mileage']) { $options['mileage'] = sanitize_text_field($input['mileage']); } else { unset($options['mileage']); }
	$options['sort_code'] = sanitize_text_field($input['sort_code']);
	$options['account_number'] = sanitize_text_field($input['account_number']);
	if (isset($input['cheques']) && $input['cheques']) { $options['cheques'] = sanitize_text_field($input['cheques']); } else { unset($options['cheques']); }
	if (isset($input['paypal']) && $input['paypal']) { $options['paypal'] = sanitize_text_field($input['paypal']); } else { unset($options['paypal']); }
	if (isset($input['recurrent']) && $input['recurrent']) { $options['recurrent'] = sanitize_text_field($input['recurrent']); } else { unset($options['recurrent']); }

	if (get_option('wp_accounts_purchased') == true) {

    	if (isset($input['company_logo'])) { $options['company_logo'] = (absint($input['company_logo']) == 0) ? NULL : absint($input['company_logo']); }
    	$options['email_color'] = sanitize_text_field($input['email_color']);
    	$options['link_color'] = sanitize_text_field($input['link_color']);
    	$options['hover_color'] = sanitize_text_field($input['hover_color']);
    	$options['email_font'] = sanitize_text_field($input['email_font']);
    	$options['email_footer'] = wp_kses_post($input['email_footer']);
    	$options['company_google_place_id'] = sanitize_text_field($input['company_google_place_id']);
        if (isset($input['email_advert'])) { $options['email_advert'] = (absint($input['email_advert']) == 0) ? NULL : absint($input['email_advert']); }

	}

	return $options;
}

function wpa_ajax_get_attachment_url() {
    check_ajax_referer('wpaccounts', 'security');
    if (isset($_GET['id']) && absint($_GET['id']) > 0) {
        $url = wp_get_attachment_url(absint($_GET['id']));
        $data = array(
            'url'    => $url
        );
        wp_send_json_success( $data );
    } else {
        wp_send_json_error();
    }
}

function wpa_enqueue_settings_script($hook_suffix) {
    wp_enqueue_media();
    wp_enqueue_style('wp-color-picker');
    wp_enqueue_script('wpa-settings-pickers');
}


function wpa_enqueue_date_picker($hook_suffix) {
    wp_enqueue_script('jquery-ui-datepicker');
    wp_enqueue_style('jquery-ui');
    wp_enqueue_script('wpa-date-pickers');
}

function wpa_accounts_settings_page() {
?>
<div>
<h2>WP Accounts Settings</h2>
<p>Set these options before using this plugin.</p>
<form action="options.php" method="post">

<?php wp_nonce_field('wpaccounts'); ?>

<?php settings_fields('wp_accounts_options'); ?>
<?php do_settings_sections('wp_accounts'); ?>
<input name="Submit" type="submit" value="<?php esc_attr_e('Save Changes'); ?>" />
</form></div>
<?php
}

function wpa_accounts_get_data($database, $receipt = false) {
    global $wpdb;
    if ($database == 'accounts_payments') {
        $data = $wpdb->get_results("SELECT " . $wpdb->prefix . "$database.ID, " . $wpdb->prefix . "$database.supplier, " . $wpdb->prefix . "$database.invoice_date, " . $wpdb->prefix . "$database.amount, " . $wpdb->prefix . "$database.reference, " . $wpdb->prefix . "$database.expense_type, " . $wpdb->prefix . "$database.date_paid, " . $wpdb->prefix . "accounts_payment_methods.payment_method, " . $wpdb->prefix . "$database.mileage, " . $wpdb->prefix . "$database.notes FROM " . $wpdb->prefix . "$database INNER JOIN " . $wpdb->prefix . "accounts_payment_methods ON " . $wpdb->prefix . "$database.payment_method = " . $wpdb->prefix . "accounts_payment_methods.ID WHERE (" . $wpdb->prefix . "$database.invoice_date >= (CURDATE() - INTERVAL 1 YEAR) OR " . $wpdb->prefix . "$database.date_paid >= (CURDATE() - INTERVAL 1 YEAR)) ORDER BY " . $wpdb->prefix . "$database.payment_method ASC, " . $wpdb->prefix . "$database.date_paid DESC, " . $wpdb->prefix . "$database.invoice_date DESC;");
    } elseif ($database == 'accounts_clients') {
        $data = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "$database ORDER BY SUBSTRING(UPPER(company), IF (UPPER(company) LIKE 'THE %', 5, 1)), contact ASC;");
    } elseif ($database == 'accounts_invoices_last_year') {

        $data = $wpdb->get_results("

SELECT * FROM {$wpdb->prefix}accounts_invoices
WHERE invoice_date >= STR_TO_DATE(CONCAT('1-',MONTH(DATE_ADD(CURDATE(), INTERVAL 1 MONTH)),'-',YEAR(DATE_ADD(DATE_SUB(CURDATE(), INTERVAL 1 YEAR), INTERVAL 1 MONTH))),'%d-%m-%Y')
AND invoice_date < STR_TO_DATE(CONCAT('1-',MONTH(DATE_ADD(CURDATE(), INTERVAL 2 MONTH)),'-',YEAR(DATE_ADD(DATE_SUB(CURDATE(), INTERVAL 1 YEAR), INTERVAL 2 MONTH))),'%d-%m-%Y')
AND yearly = 1
ORDER BY invoice_date

        ");

    } elseif ($database == 'accounts_invoices_last_month') {

        $data = $wpdb->get_results("

SELECT * FROM {$wpdb->prefix}accounts_invoices
WHERE invoice_date >= STR_TO_DATE(CONCAT('1-',MONTH(DATE_SUB(CURDATE(), INTERVAL 1 MONTH)),'-',YEAR(DATE_SUB(CURDATE(), INTERVAL 1 MONTH))),'%d-%m-%Y')
AND invoice_date < STR_TO_DATE(CONCAT('1-',MONTH(CURDATE()),'-',YEAR(CURDATE())),'%d-%m-%Y')
AND monthly = 1
ORDER BY invoice_date

        ");

    } elseif ($receipt == true) {
        $data = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "$database WHERE invoice_status <> 1 AND (invoice_date >= (CURDATE() - INTERVAL 1 YEAR) OR date_paid >= (CURDATE() - INTERVAL 1 YEAR)) ORDER BY ID DESC, invoice_date DESC;");
    } else {
        $data = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "$database WHERE invoice_status = 1 ORDER BY ID DESC, invoice_date DESC;");
    }
    return $data;
}

function wpa_client_statement_get_data($client_id) {
    global $wpdb;
    $data = $wpdb->get_results($wpdb->prepare("SELECT " . $wpdb->prefix . "accounts_invoices.ID, " . $wpdb->prefix . "accounts_clients.contact, " . $wpdb->prefix . "accounts_clients.company, " . $wpdb->prefix . "accounts_clients.address1, " . $wpdb->prefix . "accounts_clients.address2, " . $wpdb->prefix . "accounts_clients.address3, " . $wpdb->prefix . "accounts_clients.town, " . $wpdb->prefix . "accounts_clients.county, " . $wpdb->prefix . "accounts_clients.postcode, " . $wpdb->prefix . "accounts_clients.email, " . $wpdb->prefix . "accounts_invoices.invoice_date, " . $wpdb->prefix . "accounts_invoices.item1, " . $wpdb->prefix . "accounts_invoices.item2, " . $wpdb->prefix . "accounts_invoices.item3, " . $wpdb->prefix . "accounts_invoices.item4, " . $wpdb->prefix . "accounts_invoices.item5, " . $wpdb->prefix . "accounts_invoices.price1, " . $wpdb->prefix . "accounts_invoices.price2, " . $wpdb->prefix . "accounts_invoices.price3, " . $wpdb->prefix . "accounts_invoices.price4, " . $wpdb->prefix . "accounts_invoices.price5, " . $wpdb->prefix . "accounts_invoices.date_paid, " . $wpdb->prefix . "accounts_invoice_status.status, " . $wpdb->prefix . "accounts_payment_methods.payment_method FROM " . $wpdb->prefix . "accounts_invoices INNER JOIN " . $wpdb->prefix . "accounts_clients ON " . $wpdb->prefix . "accounts_invoices.client = " . $wpdb->prefix . "accounts_clients.ID INNER JOIN " . $wpdb->prefix . "accounts_invoice_status ON " . $wpdb->prefix . "accounts_invoices.invoice_status = " . $wpdb->prefix . "accounts_invoice_status.ID LEFT JOIN " . $wpdb->prefix . "accounts_payment_methods ON " . $wpdb->prefix . "accounts_invoices.payment_method = " . $wpdb->prefix . "accounts_payment_methods.ID WHERE client = %s ORDER BY invoice_date DESC;",$client_id));
    return $data;
}

function wpa_accounts_get_row($id, $database) {
    global $wpdb;
    $data = $wpdb->get_results($wpdb->prepare("SELECT * FROM " . $wpdb->prefix . "$database WHERE ID=%d;",$id));
    if(!empty($data[0])) {
        return $data[0];
    }
    return;
}

function wpa_client_from_id($id) {
    global $wpdb;
    $data = $wpdb->get_results($wpdb->prepare("SELECT company, contact, email, telephone, mobile FROM " . $wpdb->prefix . "accounts_clients WHERE ID=%d;",$id));
    if(!empty($data[0])) {
        return $data[0];
    }
    return;
}

function wpa_client_meta_box() {
    global $edit_clients;
?>
    <p>Company: <input type="text" name="accounts_clients_company" value="<?php if(isset($edit_clients)) echo esc_html($edit_clients->company);?>" /></p>
    <p>Address1:* <input type="text" name="accounts_clients_address1" value="<?php if(isset($edit_clients)) echo esc_html($edit_clients->address1);?>" /></p>
    <p>Address2: <input type="text" name="accounts_clients_address2" value="<?php if(isset($edit_clients)) echo esc_html($edit_clients->address2);?>" /></p>
    <p>Address3: <input type="text" name="accounts_clients_address3" value="<?php if(isset($edit_clients)) echo esc_html($edit_clients->address3);?>" /></p>
    <p>Town:* <input type="text" name="accounts_clients_town" value="<?php if(isset($edit_clients)) echo esc_html($edit_clients->town);?>" /></p>
    <p>County: <input type="text" name="accounts_clients_county" value="<?php if(isset($edit_clients)) echo esc_html($edit_clients->county);?>" /></p>
    <p>Postcode:* <input type="text" name="accounts_clients_postcode" value="<?php if(isset($edit_clients)) echo esc_html($edit_clients->postcode);?>" /></p>
    <p>Contact:* <input type="text" name="accounts_clients_contact" value="<?php if(isset($edit_clients)) echo esc_html($edit_clients->contact);?>" /></p>
    <p>Telephone: <input type="text" name="accounts_clients_telephone" value="<?php if(isset($edit_clients)) echo $this->wpa_format_telephone($this->wpa_clean_telephone($edit_clients->telephone));?>" /></p>
    <p>Mobile: <input type="text" name="accounts_clients_mobile" value="<?php if(isset($edit_clients)) echo $this->wpa_format_telephone($this->wpa_clean_telephone($edit_clients->mobile));?>" /></p>
    <p>Email: <input type="text" name="accounts_clients_email" value="<?php if(isset($edit_clients)) echo esc_html($edit_clients->email);?>" /></p>
    <p>Notes: <textarea name="accounts_clients_notes"><?php if(isset($edit_clients)) echo esc_html($edit_clients->notes);?></textarea></p>
    <p>(* required fields)</p>
<?php 
}

function wpa_invoice_meta_box() {
    global $edit_invoices;
    global $wpdb;

    $options = get_option('wp_accounts_options');

    $clients = $wpdb->get_results("SELECT ID, company, contact FROM " . $wpdb->prefix . "accounts_clients ORDER BY SUBSTRING(UPPER(company), IF (UPPER(company) LIKE 'THE %', 5, 1)), contact ASC;");

    if ($clients) {
?>
    <p>Client:* <select name="accounts_invoices_client">
<?php
        foreach($clients as $client) { 
?>
        <option value="<?php echo $client->ID; ?>"<?php if (isset($edit_invoices) && $edit_invoices->client == $client->ID) { echo ' selected="selected"'; } ?>><?php if ($client->company) { if (strpos(strtolower($client->company), 'the ') === 0) { echo substr($client->company, 4) . ' (The), '; } else { echo $client->company . ', '; } } echo $client->contact; ?></option>
<?php
        }
?>
    </select></p>

    <p>Invoice Date:* <input type="text" name="accounts_invoices_invoice_date" class='wpa-invoice-date' value="<?php if(isset($edit_invoices)) echo $edit_invoices->invoice_date;?>" /> YYYY-MM-DD</p>

<?php
    if (isset($options['recurrent']) && $options['recurrent'] == 'true') {
?>

    <p>Recurrence: <select name="accounts_invoices_recurrence">
        <option value=""<?php if ((isset($edit_invoices) && $edit_invoices->monthly == false && $edit_invoices->yearly == false) || !isset($edit_invoices)) { echo ' selected="selected"'; } ?>>None</option>
        <option value="monthly"<?php if (isset($edit_invoices) && $edit_invoices->monthly == true) { echo ' selected="selected"'; } ?>>Monthly</option>
        <option value="yearly"<?php if (isset($edit_invoices) && $edit_invoices->yearly == true) { echo ' selected="selected"'; } ?>>Yearly</option>
    </select></p>

<?php
    }
?>

    <p>Item 1:* <input type="text" name="accounts_invoices_item1" value="<?php if(isset($edit_invoices)) echo esc_html($edit_invoices->item1);?>" /></p>
    <p>Price 1:* &pound;<input type="text" name="accounts_invoices_price1" value="<?php if(isset($edit_invoices)) echo $edit_invoices->price1;?>" /></p>
    <p>Item 2: <input type="text" name="accounts_invoices_item2" value="<?php if(isset($edit_invoices)) echo esc_html($edit_invoices->item2);?>" /></p>
    <p>Price 2: &pound;<input type="text" name="accounts_invoices_price2" value="<?php if(isset($edit_invoices)) echo $edit_invoices->price2;?>" /></p>
    <p>Item 3: <input type="text" name="accounts_invoices_item3" value="<?php if(isset($edit_invoices)) echo esc_html($edit_invoices->item3);?>" /></p>
    <p>Price 3: &pound;<input type="text" name="accounts_invoices_price3" value="<?php if(isset($edit_invoices)) echo $edit_invoices->price3;?>" /></p>
    <p>Item 4: <input type="text" name="accounts_invoices_item4" value="<?php if(isset($edit_invoices)) echo  esc_html($edit_invoices->item4);?>" /></p>
    <p>Price 4: &pound;<input type="text" name="accounts_invoices_price4" value="<?php if(isset($edit_invoices)) echo $edit_invoices->price4;?>" /></p>
    <p>Item 5: <input type="text" name="accounts_invoices_item5" value="<?php if(isset($edit_invoices)) echo esc_html($edit_invoices->item5);?>" /></p>
    <p>Price 5: &pound;<input type="text" name="accounts_invoices_price5" value="<?php if(isset($edit_invoices)) echo $edit_invoices->price5;?>" /></p>

<?php
    $invoice_status = $wpdb->get_results("SELECT ID, status FROM " . $wpdb->prefix . "accounts_invoice_status ORDER BY status ASC;");
?>
    <p>Invoice Status: <select id="accounts_invoices_invoice_status" name="accounts_invoices_invoice_status" onchange="if (jQuery('#accounts_invoices_invoice_status').val() != 1) { jQuery('#wpa_invoice_form').attr('action', '?page=manage-receipts'); } else { jQuery('#wpa_invoice_form').attr('action', '?page=manage-invoices'); }">
<?php
        foreach($invoice_status as $status) { 
?>
        <option value="<?php echo $status->ID; ?>"<?php if ((isset($edit_invoices) && $edit_invoices->invoice_status == $status->ID && !isset($_GET['copy'])) || ((!isset($edit_invoices) || isset($_GET['copy'])) && $status->status == 'Unpaid')) { echo ' selected="selected"'; } ?>><?php echo $status->status; ?></option>
<?php
        }
?>
    </select></p>

    <p>Date Paid: <input type="text" name="accounts_invoices_date_paid" class='wpa-paid-date' value="<?php if(isset($edit_invoices) && !isset($_GET['copy'])) echo $edit_invoices->date_paid;?>" /> YYYY-MM-DD</p>

<?php
    $payment_methods = $wpdb->get_results("SELECT ID, payment_method FROM " . $wpdb->prefix . "accounts_payment_methods ORDER BY payment_method ASC;");
?>
    <p>Payment Method: <select name="accounts_invoices_payment_method">
        <option value=""<?php if (empty($edit_invoices->payment_method) || isset($_GET['copy']) || !isset($edit_invoices)) { echo ' selected="selected"'; } ?>>Unpaid</option>
<?php
        foreach($payment_methods as $payment_method) { 
?>
        <option value="<?php echo $payment_method->ID; ?>"<?php if (isset($edit_invoices) && $edit_invoices->payment_method == $payment_method->ID && !isset($_GET['copy'])) { echo ' selected="selected"'; } ?>><?php echo $payment_method->payment_method; ?></option>
<?php
        }
?>
    </select></p>

<?php
    if ($options['mileage'] == 'true') {
?>

    <p>Mileage: <input type="text" name="accounts_invoices_mileage" value="<?php if(isset($edit_invoices)) echo $edit_invoices->mileage;?>" /></p>

<?php
	}
?>

    <p>Notes: <textarea name="accounts_invoices_notes"><?php if(isset($edit_invoices)) echo $edit_invoices->notes;?></textarea></p>
    <p>(* required fields)</p>

<?php
    } else {
?>
    <p>First you need to add a client to the client database.</p>
<?php
    }
}

function wpa_payment_meta_box() {
    global $edit_payments;
    global $wpdb;

    $options = get_option('wp_accounts_options');
?>
    <p>Supplier:* <input type="text" name="accounts_payments_supplier" id="accounts_payments_supplier" value="<?php if(isset($edit_payments)) echo esc_html($edit_payments->supplier);?>" />

<?php
    $existing_suppliers = $wpdb->get_results("SELECT supplier FROM " . $wpdb->prefix . "accounts_payments GROUP BY supplier ORDER BY SUBSTRING(UPPER(supplier), IF (UPPER(supplier) LIKE 'THE %', 5, 1));");
?>
    <select name="accounts_payments_existing_suppliers" onchange="document.getElementById('accounts_payments_supplier').value = this.value;">
        <option value="" selected="selected">Existing suppliers ...</option>
<?php
        foreach($existing_suppliers as $existing_supplier) { 
?>
        <option value="<?php echo esc_html($existing_supplier->supplier); ?>"><?php 

            if (strpos(strtolower($existing_supplier->supplier), 'the ') === 0) { echo substr($existing_supplier->supplier, 4) . ' (The)'; } else { echo $existing_supplier->supplier; }

?></option>
<?php
        }
?>
    </select></p>
    <p>Invoice Date:* <input type="text" name="accounts_payments_invoice_date" class='wpa-invoice-date' value="<?php if(isset($edit_payments) && !isset($_GET['copy'])) echo $edit_payments->invoice_date;?>" /> YYYY-MM-DD</p>
    <p>Amount:* &pound;<input type="text" name="accounts_payments_amount" value="<?php if(isset($edit_payments)) echo $edit_payments->amount;?>" /></p>
    <p>Reference: <input type="text" name="accounts_payments_reference" value="<?php if(isset($edit_payments)) echo esc_html($edit_payments->reference);?>" /> (Their invoice number)</p>

<?php
    $expense_types = $wpdb->get_results("SELECT ID, expense_type FROM " . $wpdb->prefix . "accounts_expense_types ORDER BY expense_type ASC;");
?>
    <p>Expense Type:* <select name="accounts_payments_expense_type">
        <option value=""<?php if (empty($edit_payments->expense_type) || !isset($edit_payments)) { echo ' selected="selected"'; } ?>>Select ...</option>
<?php
        foreach($expense_types as $expense_type) { 
?>
        <option value="<?php echo $expense_type->ID; ?>"<?php if (isset($edit_payments) && $edit_payments->expense_type == $expense_type->ID) { echo ' selected="selected"'; } ?>><?php echo $expense_type->expense_type; ?></option>
<?php
        }
?>
    </select></p>

    <p>Date Paid:* <input type="text" name="accounts_payments_date_paid" class='wpa-paid-date' value="<?php if(isset($edit_payments) && !isset($_GET['copy'])) echo $edit_payments->date_paid;?>" /> YYYY-MM-DD</p>

<?php
    $payment_methods = $wpdb->get_results("SELECT ID, payment_method FROM " . $wpdb->prefix . "accounts_payment_methods ORDER BY payment_method ASC;");
?>
    <p>Payment Method*: <select name="accounts_payments_payment_method">
        <option value=""<?php if (empty($edit_payments->payment_method) || !isset($edit_payments)) { echo ' selected="selected"'; } ?>>Select ...</option>
<?php
        foreach($payment_methods as $payment_method) { 
?>
        <option value="<?php echo $payment_method->ID; ?>"<?php if (isset($edit_payments) && $edit_payments->payment_method == $payment_method->ID) { echo ' selected="selected"'; } ?>><?php echo $payment_method->payment_method; ?></option>
<?php
        }
?>
    </select></p>

    <p>Nature of Expense: <textarea name="accounts_payments_notes"><?php if(isset($edit_payments)) echo $edit_payments->notes;?></textarea></p>

<?php
    if ($options['mileage'] == 'true') {
?>

    <p>Mileage: <input type="text" name="accounts_payments_mileage" value="<?php if(isset($edit_payments)) echo $edit_payments->mileage;?>" /></p>

<?php
	}
?>

    <p>(* required fields)</p>

<?php 
}

function wpa_manage_invoices_options(){
    $receipt = false;
    $receipt = $this->wpa_invoices_action($receipt);
    if (empty($_GET['edit'])) {
        if (!isset($_GET['copy_yearly']) && !isset($_GET['copy_monthly'])) {
            $this->wpa_manage_invoices($receipt);
        }
    } else {
        $this->wpa_add_invoice();   
    }
}

function wpa_manage_receipts_options(){
    $receipt = true;
    $receipt = $this->wpa_invoices_action($receipt);
    if (empty($_GET['edit'])) {
        $this->wpa_manage_invoices($receipt);
    } else {
        $this->wpa_add_invoice();   
    }
}

function wpa_invoices_action($receipt){
    global $wpdb;

    if ($receipt == false) {
        $invoice_status = 1;
    } else {
        $invoice_status = 2;
    }

    if(current_user_can('manage_options') && isset($_GET['delete'])) {

		check_admin_referer('wpaccounts');

        $invoice_id = absint($_GET['delete']);
        $wpdb->query($wpdb->prepare("DELETE FROM " . $wpdb->prefix . "accounts_invoices WHERE ID=%d;",$invoice_id));
    }

    if(current_user_can('manage_options') && isset($_POST['accounts_invoices_action']) && isset($_POST['accounts_invoices_action-2']) && ($_POST['accounts_invoices_action'] == 'send' || $_POST['accounts_invoices_action-2'] == 'send')) {

        foreach ($_POST['invoice_id'] as $invoice_id) {

            $this->wpa_send_invoice($invoice_id);

        }

    }

    if(current_user_can('manage_options') && isset($_GET['send'])) {

        $invoice_id = absint($_GET['send']);
        $this->wpa_send_invoice($invoice_id);
    }

    if(current_user_can('manage_options') && isset($_POST['accounts_invoices_action']) && isset($_POST['accounts_invoices_action-2']) && ($_POST['accounts_invoices_action'] == 'send_copy' || $_POST['accounts_invoices_action-2'] == 'send_copy')) {

        foreach ($_POST['invoice_id'] as $invoice_id) {

            $this->wpa_send_invoice($invoice_id, true);

        }

    }

    if(current_user_can('manage_options') && isset($_GET['send_copy'])) {

        $invoice_id = absint($_GET['send_copy']);
        $this->wpa_send_invoice($invoice_id, true);

    }

    if(current_user_can('manage_options') && isset($_POST['accounts_add_invoice']) and isset($_POST['accounts_invoices_client']) and isset($_POST['accounts_invoices_invoice_date']) and isset($_POST['accounts_invoices_item1']) and isset($_POST['accounts_invoices_price1']) and isset($_POST['accounts_invoices_item2']) and isset($_POST['accounts_invoices_price2']) and isset($_POST['accounts_invoices_item3']) and isset($_POST['accounts_invoices_price3']) and isset($_POST['accounts_invoices_item4']) and isset($_POST['accounts_invoices_price4']) and isset($_POST['accounts_invoices_item5']) and isset($_POST['accounts_invoices_price5']) and isset($_POST['accounts_invoices_invoice_status']) and isset($_POST['accounts_invoices_date_paid']) and isset($_POST['accounts_invoices_payment_method']) and isset($_POST['accounts_invoices_notes']) ) {

		check_admin_referer('wpaccounts');

		$_POST = array_map( 'stripslashes_deep', $_POST);

        $client = (is_numeric($_POST['accounts_invoices_client']) && !empty($_POST['accounts_invoices_client'])) ? $_POST['accounts_invoices_client'] : NULL;
        $invoice_date = (strtotime(sanitize_text_field($_POST['accounts_invoices_invoice_date'])) && !empty($_POST['accounts_invoices_invoice_date'])) ? sanitize_text_field($_POST['accounts_invoices_invoice_date']) : NULL;

        if (isset($_POST['accounts_invoices_recurrence']) && $_POST['accounts_invoices_recurrence'] == 'monthly') {
		$monthly = 1;
		$yearly = 0;
	} elseif (isset($_POST['accounts_invoices_recurrence']) && $_POST['accounts_invoices_recurrence'] == 'yearly') {
		$monthly = 0;
		$yearly = 1;
	} else {
		$monthly = 0;
		$yearly = 0;
	}

        $item1 = empty($_POST['accounts_invoices_item1']) ? NULL : sanitize_text_field($_POST['accounts_invoices_item1']);
        $price1 = (is_numeric($_POST['accounts_invoices_price1']) && !empty($_POST['accounts_invoices_price1'])) ? $_POST['accounts_invoices_price1'] : NULL;
        $item2 = empty($_POST['accounts_invoices_item2']) ? NULL : sanitize_text_field($_POST['accounts_invoices_item2']);
        $price2 = (is_numeric($_POST['accounts_invoices_price2']) && !empty($_POST['accounts_invoices_price2'])) ? $_POST['accounts_invoices_price2'] : NULL;
        $item3 = empty($_POST['accounts_invoices_item3']) ? NULL : sanitize_text_field($_POST['accounts_invoices_item3']);
        $price3 = (is_numeric($_POST['accounts_invoices_price3']) && !empty($_POST['accounts_invoices_price3'])) ? $_POST['accounts_invoices_price3'] : NULL;
        $item4 = empty($_POST['accounts_invoices_item4']) ? NULL : sanitize_text_field($_POST['accounts_invoices_item4']);
        $price4 = (is_numeric($_POST['accounts_invoices_price4']) && !empty($_POST['accounts_invoices_price4'])) ? $_POST['accounts_invoices_price4'] : NULL;
        $item5 = empty($_POST['accounts_invoices_item5']) ? NULL : sanitize_text_field($_POST['accounts_invoices_item5']);
        $price5 = (is_numeric($_POST['accounts_invoices_price5']) && !empty($_POST['accounts_invoices_price5'])) ? $_POST['accounts_invoices_price5'] : NULL;
        $invoice_status = (is_numeric($_POST['accounts_invoices_invoice_status']) && !empty($_POST['accounts_invoices_invoice_status'])) ? $_POST['accounts_invoices_invoice_status'] : NULL;
        $date_paid = (strtotime(sanitize_text_field($_POST['accounts_invoices_date_paid'])) && !empty($_POST['accounts_invoices_date_paid'])) ? sanitize_text_field($_POST['accounts_invoices_date_paid']) : NULL;
        $payment_method = (is_numeric($_POST['accounts_invoices_payment_method']) && !empty($_POST['accounts_invoices_payment_method'])) ? $_POST['accounts_invoices_payment_method'] : NULL;
        $mileage = (isset($_POST['accounts_invoices_mileage']) && is_numeric($_POST['accounts_invoices_mileage'])) ? $_POST['accounts_invoices_mileage'] : NULL;
        $notes = empty($_POST['accounts_invoices_notes']) ? NULL : sanitize_text_field($_POST['accounts_invoices_notes']);

        if(empty($_POST['accounts_invoices_id'])) {
            if ($wpdb->insert(
	        $wpdb->prefix . 'accounts_invoices',
	            array(
		        'client' => $client,
		        'invoice_date' => $invoice_date,
	        	'monthly' => $monthly,
	        	'yearly' => $yearly,
	        	'item1' => $item1,
	        	'price1' => $price1,
	        	'item2' => $item2,
	        	'price2' => $price2,
	        	'item3' => $item3,
	        	'price3' => $price3,
	        	'item4' => $item4,
	        	'price4' => $price4,
	        	'item5' => $item5,
	        	'price5' => $price5,
	        	'invoice_status' => $invoice_status,
	        	'date_paid' => $date_paid,
	        	'payment_method' => $payment_method,
	        	'mileage' => $mileage,
	        	'notes' => $notes
	            ), 
	            array(
	        	'%d',
	        	'%s',
	        	'%d',
	        	'%d',
	        	'%s',
	        	'%f',
	        	'%s',
	        	'%f',
	        	'%s',
	        	'%f',
	        	'%s',
        		'%f',
	        	'%s',
	        	'%f',
	        	'%d',
	        	'%s',
	        	'%d',
	        	'%d',
        		'%s'
	            )
            ) != false) {
                echo '<p style="color: green;">Invoice Insert Success</p>';
            } else {

                echo '<p style="color: red; font-size: 2em;">Invoice Insert Fail</p>';
                echo $wpdb->last_error;

            }
        } elseif (is_numeric($_POST['accounts_invoices_id'])) {
            if ($wpdb->update(
	        $wpdb->prefix . 'accounts_invoices',
	            array(
		        'client' => $client,
		        'invoice_date' => $invoice_date,
	        	'monthly' => $monthly,
	        	'yearly' => $yearly,
	        	'item1' => $item1,
	        	'price1' => $price1,
	        	'item2' => $item2,
	        	'price2' => $price2,
	        	'item3' => $item3,
	        	'price3' => $price3,
	        	'item4' => $item4,
	        	'price4' => $price4,
	        	'item5' => $item5,
	        	'price5' => $price5,
	        	'invoice_status' => $invoice_status,
	        	'date_paid' => $date_paid,
	        	'payment_method' => $payment_method,
	        	'mileage' => $mileage,
	        	'notes' => $notes
	            ),
	            array( 'ID' => $_POST['accounts_invoices_id'] ),
	            array(
	        	'%d',
	        	'%s',
	        	'%d',
	        	'%d',
	        	'%s',
	        	'%f',
	        	'%s',
	        	'%f',
	        	'%s',
	        	'%f',
	        	'%s',
        		'%f',
	        	'%s',
	        	'%f',
	        	'%d',
	        	'%s',
	        	'%d',
	        	'%d',
        		'%s'
	            ), 
	            array( '%d' )
            ) != false) {
                echo '<p style="color: green;">Invoice Update Success</p>';
            } else {

                echo '<p style="color: red; font-size: 2em;">Invoice Update Fail</p>';
                echo $wpdb->last_error;

            }
        }
    }

    if(current_user_can('manage_options') && isset($_GET['copy_yearly'])) {

        if ($_GET['copy_yearly'] == 'true') {

            $this->wpa_locate_last_years_invoices();

        }

    }

    if(current_user_can('manage_options') && isset($_GET['copy_monthly'])) {

        if ($_GET['copy_monthly'] == 'true') {

            $this->wpa_locate_last_months_invoices();

        }

    }

    if(current_user_can('manage_options') && isset($_POST['accounts_invoices_action']) && isset($_POST['accounts_invoices_action-2']) && ($_POST['accounts_invoices_action'] == 'copy_yearly' || $_POST['accounts_invoices_action-2'] == 'copy_yearly')) {

        foreach ($_POST['invoice_id'] as $invoice_id) {

            $wpdb->query($wpdb->prepare("

INSERT INTO {$wpdb->prefix}accounts_invoices
SELECT NULL AS ID, client, DATE_ADD(invoice_date, INTERVAL 1 YEAR) AS invoice_date, monthly, yearly, item1, price1, item2, price2, item3, price3, item4, price4, item5, price5, 1 AS invoice_status, NULL AS date_paid, NULL AS payment_method, NULL AS notes, NULL AS mileage
FROM {$wpdb->prefix}accounts_invoices
WHERE ID = %d

            ", $invoice_id));

        }

    }

    if(current_user_can('manage_options') && isset($_POST['accounts_invoices_action']) && isset($_POST['accounts_invoices_action-2']) && ($_POST['accounts_invoices_action'] == 'copy_monthly' || $_POST['accounts_invoices_action-2'] == 'copy_monthly')) {

        foreach ($_POST['invoice_id'] as $invoice_id) {

            $wpdb->query($wpdb->prepare("

INSERT INTO {$wpdb->prefix}accounts_invoices
SELECT NULL AS ID, client, DATE_ADD(invoice_date, INTERVAL 1 MONTH) AS invoice_date, monthly, yearly, item1, price1, item2, price2, item3, price3, item4, price4, item5, price5, 1 AS invoice_status, NULL AS date_paid, NULL AS payment_method, NULL AS notes, NULL AS mileage
FROM {$wpdb->prefix}accounts_invoices
WHERE ID = %d

            ", $invoice_id));

        }

    }

    if ($invoice_status == 1) {

        return false;

    } else {

        return true;

    }

}

function wpa_add_invoice() {

    $invoice_id = 0;
    if(isset($_GET['id']) && !isset($_GET['copy'])) { $invoice_id = absint($_GET['id']); }

    global $edit_invoices;
    if (isset($_GET['id'])) $edit_invoices = $this->wpa_accounts_get_row(absint($_GET['id']),'accounts_invoices');   

    add_meta_box('accounts-meta', __('Invoice Details'), array($this, 'wpa_invoice_meta_box'), 'accounts-invoices', 'normal', 'core' );
?>

    <div class="wrap">
      <div id="faq-wrapper">
        <form method="post" id="wpa_invoice_form" action="?page=manage-invoices">

<?php wp_nonce_field('wpaccounts'); ?>

          <h2>
          <?php if( $invoice_id == 0 ) {
                $tf_title = __('Add Invoice');
          }else {
                $tf_title = __('Edit Invoice ' . $invoice_id);
          }
          echo $tf_title;
          ?>
          </h2>

<?php
        if (!isset($_GET['copy']) && $invoice_id != 0) {
?>

            <p>
                <a href="?page=manage-invoices&amp;id=<?= $invoice_id ?>&amp;edit=true&amp;copy=true" title="Copy invoice <?= $invoice_id; ?>">Copy</a> |
                <a href="?page=manage-invoices&amp;send=<?= $invoice_id ?>" onclick="return confirm('Are you sure you want to send this invoice?');">Send</a> |
                <a href="?page=manage-invoices&amp;send_copy=<?= $invoice_id ?>" onclick="return confirm('Are you sure you want to send a copy of this invoice?');">Send Copy</a> |
                <a href="?page=client-statement&amp;id=<?php echo $edit_invoices->client; ?>">Statement</a>
            </p>

<?php
        }
?>

          <div id="poststuff" class="metabox-holder">
            <?php do_meta_boxes('accounts-invoices', 'normal','low'); ?>
          </div>
          <input type="hidden" name="accounts_invoices_id" value="<?php echo $invoice_id; ?>" />
          <input type="submit" value="<?php echo $tf_title;?>" name="accounts_add_invoice" id="accounts_add_invoice" class="button-secondary" />

        </form>
      </div>
    </div>
<?php
}







function wpa_locate_last_years_invoices() {

    $options = get_option('wp_accounts_options');
?>
<div class="wrap">
  <div class="icon32" id="icon-edit"><br></div>
  <h2>Yearly Recurrent Invoices from <?= date('F Y', strtotime('-1 year +1 month')); ?></h2>

  <form method="post" action="?page=manage-invoices" id="accounts_form_action">

<?php wp_nonce_field('wpaccounts'); ?>

    <p>
        <select name="accounts_invoices_action">
            <option value="actions"><?php _e('Actions')?></option>
            <!--<option value="delete"><?php _e('Delete')?></option>-->
            <option value="send"><?php _e('Send')?></option>
            <option value="send_copy"><?php _e('Send Copy')?></option>
            <option value="copy_yearly"><?php _e('Copy into ' . date('Y'))?></option>
      </select>
      <input type="submit" name="accounts_form_action_changes" class="button-secondary" value="<?php _e('Apply')?>" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Client')?>" onclick="window.location='?page=manage-clients&edit=true'" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Invoice')?>" onclick="window.location='?page=manage-invoices&amp;edit=true'" />
    </p>
    <table class="widefat page fixed" cellpadding="0">
      <thead>
        <tr>
        <th id="cb" class="manage-column column-cb check-column" style="" scope="col">
          <input type="checkbox"/>
        </th>
          <th class="manage-column"><?php _e('ID')?></th>
          <th class="manage-column"><?php _e('Client')?></th>
          <th class="manage-column"><?php _e('Date')?></th>
          <th class="manage-column"><?php _e('Amount')?></th>
        </tr>
      </thead>
      <tfoot>
        <tr>
        <th id="cb" class="manage-column column-cb check-column" style="" scope="col">
          <input type="checkbox"/>
        </th>
          <th class="manage-column"><?php _e('ID')?></th>
          <th class="manage-column"><?php _e('Client')?></th>
          <th class="manage-column"><?php _e('Date')?></th>
          <th class="manage-column"><?php _e('Amount')?></th>
        </tr>
      </tfoot>
      <tbody>
        <?php
          $invoices = $this->wpa_accounts_get_data('accounts_invoices_last_year');
          if($invoices){
           $i=0;
           $total_price=0;
           $total_cancelled=0;
           foreach($invoices as $invoice) { 
               $i++;
               if ($invoice->invoice_status != 3) { $total_price = $total_price + $invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5; } else { $total_cancelled = $total_cancelled + $invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5; }
        ?>
      <tr class="<?php echo (ceil($i/2) == ($i/2)) ? "" : "alternate"; ?>">
        <th class="check-column" scope="row">
          <input type="checkbox" value="<?php echo $invoice->ID; ?>" name="invoice_id[]" />
        </th>
          <td>
          <strong<?php if ($invoice->invoice_status == 3) { echo ' style="color: red;"'; } ?>><?php echo $invoice->ID; ?></strong>

<?php
	if ($options['recurrent'] == 'true' && $invoice->monthly == true) {
		echo '(monthly)';
	} elseif ($options['recurrent'] == 'true' && $invoice->yearly == true) {
		echo '(yearly)';
	} 
?>

          <div class="row-actions-visible">
          <a href="?page=manage-invoices&amp;id=<?php echo $invoice->ID; ?>&amp;edit=true">Edit</a> | 
          <a href="?page=manage-invoices&amp;id=<?php echo $invoice->ID; ?>&amp;edit=true&amp;copy=true">Copy</a> |
          <!--<span class="delete"><a href="?page=manage-invoices&amp;delete=<?php echo $invoice->ID; ?>" onclick="return confirm('Are you sure you want to delete this invoice?');">Delete</a> | </span>-->
          <a href="?page=manage-invoices&amp;send=<?php echo $invoice->ID; ?>" onclick="return confirm('Are you sure you want to send this invoice?');">Send</a> |
          <a href="?page=manage-invoices&amp;send_copy=<?php echo $invoice->ID; ?>" onclick="return confirm('Are you sure you want to send a copy of this invoice?');">Send Copy</a>
          </div>
          </td>
          <td><?php $client=$this->wpa_client_from_id($invoice->client); if ($client->company) { echo $client->company . ', '; } echo $client->contact; ?><br />

          <span class="statement"><a href="?page=client-statement&amp;id=<?php echo $invoice->client; ?>">Statement</a> |
          <span class="edit"><a href="?page=manage-clients&amp;id=<?php echo $invoice->client; ?>&amp;edit=true">Edit</a></span><?php if ($client->email) { ?> |
          <span class="email"><a href="mailto:<?php echo $client->email; ?>">Email</a></span><?php } ?></td>
          <td>Raised: <?php echo date('jS F Y',strtotime($invoice->invoice_date)); ?><?php

        if ($invoice->date_paid) { echo('<br />Paid: ' . date('jS F Y',strtotime($invoice->date_paid))); }

          ?></td>
          <td<?php if ($invoice->invoice_status == 3) { echo ' style="color: red;"'; } ?>>&pound;<?php echo number_format(($invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5),2); ?></td>
        </tr>
        <?php
           }
           $i++;
        ?>
      <tr class="<?php echo (ceil($i/2) == ($i/2)) ? "" : "alternate"; ?>">
        <th class="check-column" scope="row"></th>
          <td></td>
          <td></td>

<?php if ($invoice->date_paid) { ?>

          <td style="color: red;">Cancelled: &pound;<?php echo number_format($total_cancelled,2); ?></td>

<?php } else { ?>

          <td></td>

<?php } ?>

          <td>Total: <strong>&pound;<?php echo number_format($total_price,2); ?></strong></td>
        </tr>
        <?php
        }
        else{   
      ?>
        <tr><td colspan="4"><?php _e('There are no invoices.')?></td></tr>   
        <?php
      }
        ?>   
      </tbody>
    </table>
    <p>
        <select name="accounts_invoices_action-2">
            <option value="actions"><?php _e('Actions')?></option>
            <!--<option value="delete"><?php _e('Delete')?></option>-->
            <option value="send"><?php _e('Send')?></option>
            <option value="send_copy"><?php _e('Send Copy')?></option>
            <option value="copy_yearly"><?php _e('Copy into ' . date('Y'))?></option>
        </select>
        <input type="submit" name="accounts_form_action_changes-2" class="button-secondary" value="<?php _e('Apply')?>" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Client')?>" onclick="window.location='?page=manage-clients&edit=true'" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Invoice')?>" onclick="window.location='?page=manage-invoices&amp;edit=true'" />
    </p>

  </form>
</div>
<?php
}






function wpa_locate_last_months_invoices() {

    $options = get_option('wp_accounts_options');
?>
<div class="wrap">
  <div class="icon32" id="icon-edit"><br></div>
  <h2>Monthly Recurrent Invoices from <?= date('F Y', strtotime('-1 month')); ?></h2>

  <form method="post" action="?page=manage-invoices" id="accounts_form_action">

<?php wp_nonce_field('wpaccounts'); ?>

    <p>
        <select name="accounts_invoices_action">
            <option value="actions"><?php _e('Actions')?></option>
            <!--<option value="delete"><?php _e('Delete')?></option>-->
            <option value="send"><?php _e('Send')?></option>
            <option value="send_copy"><?php _e('Send Copy')?></option>
            <option value="copy_monthly"><?php _e('Copy into ' . date('F Y'))?></option>
      </select>
      <input type="submit" name="accounts_form_action_changes" class="button-secondary" value="<?php _e('Apply')?>" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Client')?>" onclick="window.location='?page=manage-clients&edit=true'" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Invoice')?>" onclick="window.location='?page=manage-invoices&amp;edit=true'" />
    </p>
    <table class="widefat page fixed" cellpadding="0">
      <thead>
        <tr>
        <th id="cb" class="manage-column column-cb check-column" style="" scope="col">
          <input type="checkbox"/>
        </th>
          <th class="manage-column"><?php _e('ID')?></th>
          <th class="manage-column"><?php _e('Client')?></th>
          <th class="manage-column"><?php _e('Date')?></th>
          <th class="manage-column"><?php _e('Amount')?></th>
        </tr>
      </thead>
      <tfoot>
        <tr>
        <th id="cb" class="manage-column column-cb check-column" style="" scope="col">
          <input type="checkbox"/>
        </th>
          <th class="manage-column"><?php _e('ID')?></th>
          <th class="manage-column"><?php _e('Client')?></th>
          <th class="manage-column"><?php _e('Date')?></th>
          <th class="manage-column"><?php _e('Amount')?></th>
        </tr>
      </tfoot>
      <tbody>
        <?php
          $invoices = $this->wpa_accounts_get_data('accounts_invoices_last_month');
          if($invoices){
           $i=0;
           $total_price=0;
           $total_cancelled=0;
           foreach($invoices as $invoice) { 
               $i++;
               if ($invoice->invoice_status != 3) { $total_price = $total_price + $invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5; } else { $total_cancelled = $total_cancelled + $invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5; }
        ?>
      <tr class="<?php echo (ceil($i/2) == ($i/2)) ? "" : "alternate"; ?>">
        <th class="check-column" scope="row">
          <input type="checkbox" value="<?php echo $invoice->ID; ?>" name="invoice_id[]" />
        </th>
          <td>
          <strong<?php if ($invoice->invoice_status == 3) { echo ' style="color: red;"'; } ?>><?php echo $invoice->ID; ?></strong>

<?php
	if ($options['recurrent'] == 'true' && $invoice->monthly == true) {
		echo '(monthly)';
	} elseif ($options['recurrent'] == 'true' && $invoice->yearly == true) {
		echo '(yearly)';
	} 
?>

          <div class="row-actions-visible">
          <span class="edit"><a href="?page=manage-invoices&amp;id=<?php echo $invoice->ID; ?>&amp;edit=true">Edit</a> | 
          <span class="edit"><a href="?page=manage-invoices&amp;id=<?php echo $invoice->ID; ?>&amp;edit=true&amp;copy=true">Copy</a> | </span>
          <!--<span class="delete"><a href="?page=manage-invoices&amp;delete=<?php echo $invoice->ID; ?>" onclick="return confirm('Are you sure you want to delete this invoice?');">Delete</a> | </span>-->
          <span class="send"><a href="?page=manage-invoices&amp;send=<?php echo $invoice->ID; ?>" onclick="return confirm('Are you sure you want to send this invoice?');">Send</a> |
          <span class="send-copy"><a href="?page=manage-invoices&amp;send_copy=<?php echo $invoice->ID; ?>" onclick="return confirm('Are you sure you want to send a copy of this invoice?');">Send Copy</a></span>
          </div>
          </td>
          <td><?php $client=$this->wpa_client_from_id($invoice->client); if ($client->company) { echo $client->company . ', '; } echo $client->contact; ?><br />

          <span class="statement"><a href="?page=client-statement&amp;id=<?php echo $invoice->client; ?>">Statement</a> |
          <span class="edit"><a href="?page=manage-clients&amp;id=<?php echo $invoice->client; ?>&amp;edit=true">Edit</a></span><?php if ($client->email) { ?> |
          <span class="email"><a href="mailto:<?php echo $client->email; ?>">Email</a></span><?php } ?></td>
          <td>Raised: <?php echo date('jS F Y',strtotime($invoice->invoice_date)); ?><?php

        if ($invoice->date_paid) { echo('<br />Paid: ' . date('jS F Y',strtotime($invoice->date_paid))); }

          ?></td>
          <td<?php if ($invoice->invoice_status == 3) { echo ' style="color: red;"'; } ?>>&pound;<?php echo number_format(($invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5),2); ?></td>
        </tr>
        <?php
           }
           $i++;
        ?>
      <tr class="<?php echo (ceil($i/2) == ($i/2)) ? "" : "alternate"; ?>">
        <th class="check-column" scope="row"></th>
          <td></td>
          <td></td>

<?php if ($invoice->date_paid) { ?>

          <td style="color: red;">Cancelled: &pound;<?php echo number_format($total_cancelled,2); ?></td>

<?php } else { ?>

          <td></td>

<?php } ?>

          <td>Total: <strong>&pound;<?php echo number_format($total_price,2); ?></strong></td>
        </tr>
        <?php
        }
        else{   
      ?>
        <tr><td colspan="4"><?php _e('There are no invoices.')?></td></tr>   
        <?php
      }
        ?>   
      </tbody>
    </table>
    <p>
        <select name="accounts_invoices_action-2">
            <option value="actions"><?php _e('Actions')?></option>
            <!--<option value="delete"><?php _e('Delete')?></option>-->
            <option value="send"><?php _e('Send')?></option>
            <option value="send_copy"><?php _e('Send Copy')?></option>
            <option value="copy_monthly"><?php _e('Copy into ' . date('F Y'))?></option>
        </select>
        <input type="submit" name="accounts_form_action_changes-2" class="button-secondary" value="<?php _e('Apply')?>" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Client')?>" onclick="window.location='?page=manage-clients&edit=true'" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Invoice')?>" onclick="window.location='?page=manage-invoices&amp;edit=true'" />
    </p>

  </form>
</div>
<?php
}







function wpa_manage_invoices($receipt){
	$options = get_option('wp_accounts_options');
?>
<div class="wrap">
  <div class="icon32" id="icon-edit"><br></div>
  <h2><?php if ($receipt == true) { _e('Manage Receipts'); } else { _e('Manage Invoices'); } ?></h2>

<?php
	if (isset($options['recurrent']) && $options['recurrent'] == 'true') {
?>

<p><a href="?page=manage-invoices&amp;copy_yearly=true">View yearly recurrent invoices from <?= date('F Y', strtotime('-1 year +1 month')); ?></a></p>

<p><a href="?page=manage-invoices&amp;copy_monthly=true">View monthly recurrent invoices from <?= date('F Y', strtotime('-1 month')); ?></a></p>

<?php
	} 
?>

  <form method="get" action="" id="accounts_form_action">

<?php wp_nonce_field('wpaccounts'); ?>

    <p><input type="hidden" name="page" value="manage-invoices" />Edit <?php if ($receipt == true) { _e('Receipt'); } else { _e('Invoice'); } ?>: <input name="id" size="10" type="text" value="" /> <input type="submit" name="submit" class="button-secondary" value="Edit" /><input type="hidden" name="edit" value="true" /></p>
  </form>

  <form method="post" action="?page=manage-invoices" id="accounts_form_action">

<?php wp_nonce_field('wpaccounts'); ?>

    <p>
        <select name="accounts_invoices_action">
            <option value="actions"><?php _e('Actions')?></option>
            <!--<option value="delete"><?php _e('Delete')?></option>-->
            <option value="send"><?php _e('Send')?></option>
            <option value="send_copy"><?php _e('Send Copy')?></option>
      </select>
      <input type="submit" name="accounts_form_action_changes" class="button-secondary" value="<?php _e('Apply')?>" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Client')?>" onclick="window.location='?page=manage-clients&edit=true'" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Invoice')?>" onclick="window.location='?page=manage-invoices&amp;edit=true'" />
    </p>
    <table class="widefat page fixed" cellpadding="0">
      <thead>
        <tr>
        <th id="cb" class="manage-column column-cb check-column" style="" scope="col">
          <input type="checkbox"/>
        </th>
          <th class="manage-column"><?php _e('ID')?></th>
          <th class="manage-column"><?php _e('Client')?></th>
          <th class="manage-column"><?php _e('Date')?></th>
          <th class="manage-column"><?php _e('Amount')?></th>
        </tr>
      </thead>
      <tfoot>
        <tr>
        <th id="cb" class="manage-column column-cb check-column" style="" scope="col">
          <input type="checkbox"/>
        </th>
          <th class="manage-column"><?php _e('ID')?></th>
          <th class="manage-column"><?php _e('Client')?></th>
          <th class="manage-column"><?php _e('Date')?></th>
          <th class="manage-column"><?php _e('Amount')?></th>
        </tr>
      </tfoot>
      <tbody>
        <?php
          $invoices = $this->wpa_accounts_get_data('accounts_invoices', $receipt);
          if($invoices){
           $i=0;
           $total_price=0;
           $total_cancelled=0;
           foreach($invoices as $invoice) { 
               $i++;
               if ($invoice->invoice_status != 3) { $total_price = $total_price + $invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5; } else { $total_cancelled = $total_cancelled + $invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5; }
        ?>
      <tr class="<?php echo (ceil($i/2) == ($i/2)) ? "" : "alternate"; ?>">
        <th class="check-column" scope="row">
          <input type="checkbox" value="<?php echo $invoice->ID; ?>" name="invoice_id[]" />
        </th>
          <td>
          <strong<?php if ($invoice->invoice_status == 3) { echo ' style="color: red;"'; } ?>><?php echo $invoice->ID; ?></strong>

<?php
	if (isset($options['recurrent']) && $options['recurrent'] == 'true' && $invoice->monthly == true) {
		echo '(monthly)';
	} elseif (isset($options['recurrent']) && $options['recurrent'] == 'true' && $invoice->yearly == true) {
		echo '(yearly)';
	} 
?>

          <div class="row-actions-visible">
          <span class="edit"><a href="?page=manage-invoices&amp;id=<?php echo $invoice->ID; ?>&amp;edit=true">Edit</a> | 
          <span class="edit"><a href="?page=manage-invoices&amp;id=<?php echo $invoice->ID; ?>&amp;edit=true&amp;copy=true">Copy</a> | </span>
          <!--<span class="delete"><a href="?page=manage-invoices&amp;delete=<?php echo $invoice->ID; ?>" onclick="return confirm('Are you sure you want to delete this invoice?');">Delete</a> | </span>-->
          <span class="send"><a href="?page=manage-invoices&amp;send=<?php echo $invoice->ID; ?>" onclick="return confirm('Are you sure you want to send this invoice?');">Send</a> |
          <span class="send-copy"><a href="?page=manage-invoices&amp;send_copy=<?php echo $invoice->ID; ?>" onclick="return confirm('Are you sure you want to send a copy of this invoice?');">Send Copy</a></span>
          </div>
          </td>
          <td><strong><?php $client=$this->wpa_client_from_id($invoice->client); if ($client->company) { echo $client->company . ', '; } echo $client->contact; ?></strong><br />
<?php

    if (isset($client->telephone) || isset($client->mobile)) {

?>
          <span class="telephone">
<?php

        if (isset($client->telephone)) {

?>
Tel: <?= $this->wpa_format_telephone($this->wpa_clean_telephone($client->telephone)); ?>
<?php

            if (isset($client->mobile)) {

?>
 | 
<?php

            }

        }

        if (isset($client->mobile)) {

?>
Mob: <?= $this->wpa_format_telephone($this->wpa_clean_telephone($client->mobile)); ?>
<?php

        }

?>
</span><br />
<?php

    }

?>

          <span class="statement"><a href="?page=client-statement&amp;id=<?php echo $invoice->client; ?>">Statement</a> |
          <span class="edit"><a href="?page=manage-clients&amp;id=<?php echo $invoice->client; ?>&amp;edit=true">Edit</a></span><?php if ($client->email) { ?> |
          <span class="email"><a href="mailto:<?php echo $client->email; ?>">Email</a></span><?php } ?></td>
          <td>Raised: <?php echo date('jS F Y',strtotime($invoice->invoice_date)); ?><?php

        if ($receipt == true) { echo('<br />Paid: ' . date('jS F Y',strtotime($invoice->date_paid))); }

          ?></td>
          <td<?php if ($invoice->invoice_status == 3) { echo ' style="color: red;"'; } ?>>&pound;<?php echo number_format(($invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5),2); ?></td>
        </tr>
        <?php
           }
           $i++;
        ?>
      <tr class="<?php echo (ceil($i/2) == ($i/2)) ? "" : "alternate"; ?>">
        <th class="check-column" scope="row"></th>
          <td></td>
          <td></td>

<?php if ($receipt == true) { ?>

          <td style="color: red;">Cancelled: &pound;<?php echo number_format($total_cancelled,2); ?></td>

<?php } else { ?>

          <td></td>

<?php } ?>

          <td>Total: <strong>&pound;<?php echo number_format($total_price,2); ?></strong></td>
        </tr>
        <?php
        }
        else{   
      ?>
        <tr><td colspan="4"><?php _e('There are no invoices.')?></td></tr>   
        <?php
      }
        ?>   
      </tbody>
    </table>
    <p>
        <select name="accounts_invoices_action-2">
            <option value="actions"><?php _e('Actions')?></option>
            <!--<option value="delete"><?php _e('Delete')?></option>-->
            <option value="send"><?php _e('Send')?></option>
            <option value="send_copy"><?php _e('Send Copy')?></option>
        </select>
        <input type="submit" name="accounts_form_action_changes-2" class="button-secondary" value="<?php _e('Apply')?>" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Client')?>" onclick="window.location='?page=manage-clients&edit=true'" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Invoice')?>" onclick="window.location='?page=manage-invoices&amp;edit=true'" />
    </p>

  </form>
</div>
<?php
}

function wpa_manage_clients_options(){
    $this->wpa_clients_action();
    if (empty($_GET['edit'])) {
        $this->wpa_manage_clients();
    } else {
        $this->wpa_add_client();   
    }
}

function wpa_clients_action(){
    global $wpdb;

    if(current_user_can('manage_options') && isset($_GET['delete'])) {

		check_admin_referer('wpaccounts');

        $client_id = absint($_GET['delete']);
        $wpdb->query($wpdb->prepare("DELETE FROM " . $wpdb->prefix . "accounts_clients WHERE ID=%d;",$client_id));
    }

    if(current_user_can('manage_options') && isset($_POST['accounts_add_client']) and isset($_POST['accounts_clients_company']) and isset($_POST['accounts_clients_address1']) and isset($_POST['accounts_clients_address2']) and isset($_POST['accounts_clients_address3']) and isset($_POST['accounts_clients_town']) and isset($_POST['accounts_clients_county']) and isset($_POST['accounts_clients_postcode']) and isset($_POST['accounts_clients_contact']) and isset($_POST['accounts_clients_telephone']) and isset($_POST['accounts_clients_mobile']) and isset($_POST['accounts_clients_email']) and isset($_POST['accounts_clients_notes']) ) {

		check_admin_referer('wpaccounts');

		$_POST = array_map( 'stripslashes_deep', $_POST);

        $company = empty($_POST['accounts_clients_company']) ? NULL : sanitize_text_field($_POST['accounts_clients_company']);
        $address1 = empty($_POST['accounts_clients_address1']) ? NULL : sanitize_text_field($_POST['accounts_clients_address1']);
        $address2 = empty($_POST['accounts_clients_address2']) ? NULL : sanitize_text_field($_POST['accounts_clients_address2']);
        $address3 = empty($_POST['accounts_clients_address3']) ? NULL : sanitize_text_field($_POST['accounts_clients_address3']);
        $town = empty($_POST['accounts_clients_town']) ? NULL : sanitize_text_field($_POST['accounts_clients_town']);
        $county = empty($_POST['accounts_clients_county']) ? NULL : sanitize_text_field($_POST['accounts_clients_county']);
        $postcode = empty($_POST['accounts_clients_postcode']) ? NULL : sanitize_text_field($_POST['accounts_clients_postcode']);
        $contact = empty($_POST['accounts_clients_contact']) ? NULL : sanitize_text_field($_POST['accounts_clients_contact']);
        $telephone = empty($_POST['accounts_clients_telephone']) ? NULL : $this->wpa_clean_telephone($_POST['accounts_clients_telephone']);
        $mobile = empty($_POST['accounts_clients_mobile']) ? NULL : $this->wpa_clean_telephone($_POST['accounts_clients_mobile']);
        $email = empty($_POST['accounts_clients_email']) ? NULL : sanitize_text_field($_POST['accounts_clients_email']);
        $notes = empty($_POST['accounts_clients_notes']) ? NULL : sanitize_text_field($_POST['accounts_clients_notes']);

        if(empty($_POST['accounts_clients_id'])) {
            if ($wpdb->insert(
	        $wpdb->prefix . 'accounts_clients',
	            array(
		        'company' => $company,
		        'address1' => $address1,
	        	'address2' => $address2,
	        	'address3' => $address3,
	        	'town' => $town,
	        	'county' => $county,
	        	'postcode' => $postcode,
	        	'contact' => $contact,
	        	'telephone' => $telephone,
	        	'mobile' => $mobile,
	        	'email' => $email,
	        	'notes' => $notes
	            ), 
	            array(
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
        		'%s'
	            )
            ) != false) {
                echo '<p style="color: green;">Client Insert Success</p>';
            } else {
                echo '<p style="color: red; font-size: 2em;">Client Insert Fail</p>';
echo $wpdb->last_error;
            }
        } elseif (is_numeric($_POST['accounts_clients_id'])) {
            if ($wpdb->update(
	        $wpdb->prefix . 'accounts_clients',
	            array(
		        'company' => $company,
		        'address1' => $address1,
	        	'address2' => $address2,
	        	'address3' => $address3,
	        	'town' => $town,
	        	'county' => $county,
	        	'postcode' => $postcode,
	        	'contact' => $contact,
	        	'telephone' => $telephone,
	        	'mobile' => $mobile,
	        	'email' => $email,
	        	'notes' => $notes
	            ),
	            array( 'ID' => $_POST['accounts_clients_id'] ),
	            array(
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
	        	'%s',
        		'%s'
	            ), 
	            array( '%d' )
            ) != false) {
                echo '<p style="color: green;">Client Update Success</p>';
            } else {
                echo '<p style="color: red; font-size: 2em;">Client Update Fail</p>';
echo $wpdb->last_error;
            }
        }
    }  
}

function wpa_add_client(){
    $client_id = 0;
    if(isset($_GET['id'])) $client_id = absint($_GET['id']);

    global $edit_clients;
    if ($client_id) $edit_clients = $this->wpa_accounts_get_row($client_id,'accounts_clients');   

    add_meta_box('accounts-meta', __('Client Details'), array($this, 'wpa_client_meta_box'), 'accounts-clients', 'normal', 'core' );
?>

    <div class="wrap">
      <div id="faq-wrapper">
        <form method="post" action="?page=manage-clients">

<?php wp_nonce_field('wpaccounts'); ?>

          <h2>
          <?php if( $client_id == 0 ) {
                $tf_title = __('Add Client');
          }else {
                $tf_title = __('Edit Client');
          }
          echo $tf_title;
          ?>
          </h2>

<?php
        if ($client_id != 0) {
?>

            <p>
                <a href="?page=client-statement&amp;id=<?= $client_id; ?>">Statement</a>
            </p>

<?php
        }
?>

          <div id="poststuff" class="metabox-holder">
            <?php do_meta_boxes('accounts-clients', 'normal','low'); ?>
          </div>
          <input type="hidden" name="accounts_clients_id" value="<?php echo $client_id; ?>" />
          <input type="submit" value="<?php echo $tf_title;?>" name="accounts_add_client" id="accounts_add_client" class="button-secondary">
        </form>
      </div>
    </div>
<?php
}

function wpa_manage_clients() {
?>
<div class="wrap">
  <div class="icon32" id="icon-edit"><br></div>
  <h2><?php _e('Manage Clients') ?></h2>
  <form method="post" action="?page=manage-clients" id="accounts_form_action">

<?php wp_nonce_field('wpaccounts'); ?>

    <p>
        <select name="accounts_clients_action">
            <option value="actions"><?php _e('Actions')?></option>
            <!--<option value="delete"><?php _e('Delete')?></option>-->
      </select>
      <input type="submit" name="accounts_form_action_changes" class="button-secondary" value="<?php _e('Apply')?>" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Client')?>" onclick="window.location='?page=manage-clients&amp;edit=true'" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Invoice')?>" onclick="window.location='?page=manage-invoices&amp;edit=true'" />
    </p>
    <table class="widefat page fixed" cellpadding="0">
      <thead>
        <tr>
        <th id="cb" class="manage-column column-cb check-column" style="" scope="col">
          <input type="checkbox"/>
        </th>
          <th class="manage-column"><?php _e('Company')?></th>
          <th class="manage-column"><?php _e('Town')?></th>
          <th class="manage-column"><?php _e('Telephone')?></th>
          <th class="manage-column"><?php _e('Mobile')?></th>
        </tr>
      </thead>
      <tfoot>
        <tr>
        <th id="cb" class="manage-column column-cb check-column" style="" scope="col">
          <input type="checkbox"/>
        </th>
          <th class="manage-column"><?php _e('Company')?></th>
          <th class="manage-column"><?php _e('Town')?></th>
          <th class="manage-column"><?php _e('Telephone')?></th>
          <th class="manage-column"><?php _e('Mobile')?></th>
        </tr>
      </tfoot>
      <tbody>
        <?php
          $clients = $this->wpa_accounts_get_data('accounts_clients', false);
          if($clients){
           $i=0;
           foreach($clients as $client) { 
               $i++;
        ?>
      <tr class="<?php echo (ceil($i/2) == ($i/2)) ? "" : "alternate"; ?>">
        <th class="check-column" scope="row">
          <input type="checkbox" value="<?php echo $client->ID; ?>" name="client_id[]" />
        </th>
          <td>
          <strong><?php if ($client->company) { if (strpos(strtolower($client->company), 'the ') === 0) { echo substr($client->company, 4) . ' (The), '; } else { echo $client->company . ', '; } } echo $client->contact; ?></strong>
          <div class="row-actions-visible">
          <span class="statement"><a href="?page=client-statement&amp;id=<?php echo $client->ID; ?>">Statement</a> |
          <span class="edit"><a href="?page=manage-clients&amp;id=<?php echo $client->ID; ?>&amp;edit=true">Edit</a></span><?php if ($client->email) { ?> |
          <span class="email"><a href="mailto:<?php echo $client->email; ?>">Email</a></span><?php } ?>
          <!--<span class="delete"><a href="?page=manage-clients&amp;delete=<?php echo $client->ID; ?>" onclick="return confirm('Are you sure you want to delete this client?');">Delete</a></span>-->
          </div>
          </td>
          <td><?php echo $client->town; ?></td>
          <td><?php echo $this->wpa_format_telephone($this->wpa_clean_telephone($client->telephone)); ?></td>
          <td><?php echo $this->wpa_format_telephone($this->wpa_clean_telephone($client->mobile)); ?></td>
        </tr>
        <?php
           }
        }
        else{   
      ?>
        <tr><td colspan="4"><?php _e('There are no clients.')?></td></tr>   
        <?php
      }
        ?>   
      </tbody>
    </table>
    <p>
        <select name="accounts_clients_action-2">
            <option value="actions"><?php _e('Actions')?></option>
            <!--<option value="delete"><?php _e('Delete')?></option>-->
        </select>
        <input type="submit" name="accounts_form_action_changes-2" class="button-secondary" value="<?php _e('Apply')?>" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Client')?>" onclick="window.location='?page=manage-clients&amp;edit=true'" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Invoice')?>" onclick="window.location='?page=manage-invoices&amp;edit=true'" />
    </p>

  </form>
</div>
<?php
}

function wpa_client_statement_options(){
    $this->wpa_clients_action();
    if (empty($_GET['id'])) {
        $this->wpa_manage_clients();
    } else {
        $this->wpa_client_statement();   
    }
}

function wpa_client_statement() {
    $client_id = absint($_GET['id']);
    $invoices = $this->wpa_client_statement_get_data($client_id);
    $options = get_option('wp_accounts_options');
    $client_name = '';
?>
<div class="wrap">
  <div class="icon32" id="icon-edit"><br></div>

<?php
    if ($invoices[0]->company) { $client_name = $invoices[0]->company . ', '; }
    $client_name .= $invoices[0]->contact;
    $client = $this->wpa_client_from_id($client_id);
?>

  <h2><?php _e($client_name . ' Statement'); ?></h2>

<p>
<?php

    if (isset($client->telephone)) {

?>
Telphone: <?= $this->wpa_format_telephone($this->wpa_clean_telephone($client->telephone)); ?><br />
<?php

    }

    if (isset($client->mobile)) {

?>
Mobile: <?= $this->wpa_format_telephone($this->wpa_clean_telephone($client->mobile)); ?><br />
<?php

    }

    if (isset($client->email)) {

?>
Email: <a href="mailto:<?= $client->email; ?>"><?= $client->email; ?></a><br />
<?php

    }
?>
<a href="?page=manage-clients&amp;id=<?= $client_id; ?>&amp;edit=true">Edit Client</a></p>

    <table class="widefat page fixed" cellpadding="0">
      <thead>
        <tr>
          <th class="manage-column"><?php _e('Invoice')?></th>
          <th class="manage-column"><?php _e('Date')?></th>
          <th class="manage-column"><?php _e('Status')?></th>
          <th class="manage-column"><?php _e('Amount')?></th>
        </tr>
      </thead>
      <tfoot>
        <tr>
          <th class="manage-column"><?php _e('Invoice')?></th>
          <th class="manage-column"><?php _e('Date')?></th>
          <th class="manage-column"><?php _e('Status')?></th>
          <th class="manage-column"><?php _e('Amount')?></th>
        </tr>
      </tfoot>
      <tbody>
        <?php
          if($invoices){
           $i=0;
           $total_due=0;
           foreach($invoices as $invoice) { 
               $i++;
               if ($invoice->status == 'Unpaid') { $total_due = $total_due + $invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5; }
        ?>
      <tr class="<?php echo (ceil($i/2) == ($i/2)) ? "" : "alternate"; ?>">
          <td>
          <strong><a href="?page=manage-invoices&amp;id=<?= $invoice->ID; ?>&amp;edit=true" title="Edit invoice <?= $invoice->ID; ?>"<?php if ($invoice->status == 'Cancelled' || $invoice->status == 'Unpaid') { echo ' style="color: red;"'; } ?>><?= $invoice->ID; ?></a></strong>
          </td>
          <td><?php echo date('jS F Y',strtotime($invoice->invoice_date)); ?></td>
          <td><?php

if ($invoice->status == 'Paid') {
  echo 'Paid by ' . $invoice->payment_method . ' on ' . mysql2date('jS F Y', $invoice->date_paid);
} else {
  echo '<span style="color: red;">' . $invoice->status . '</span>';
}

?></td>
          <td<?php if (isset($invoice->invoice_status) && $invoice->invoice_status == 3) { echo ' style="color: red;"'; } ?> align="right">&pound;<?php echo number_format(($invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5),2); ?></td>
        </tr>
        <?php
           }
           $i++;
        ?>
      <tr class="<?php echo (ceil($i/2) == ($i/2)) ? "" : "alternate"; ?>">
          <td></td>
          <td></td>
          <td></td>
          <td style="color: red;" align="right">Due Now: <strong>&pound;<?php echo number_format($total_due,2); ?></strong></td>
        </tr>
        <?php
        }
        else{   
      ?>
        <tr><td colspan="4"><?php _e('There are no invoices.')?></td></tr>   
        <?php
      }
        ?>
      </tbody>
    </table>

</div>

<?php

	if (isset($_GET['activate']) && $_GET['activate'] == 'true') {
		$this->wpa_activate();
	}

?>
<div class="wrap">
<h2><?php _e('Download Statement'); ?></h2>

<?php
	if (get_option('wp_accounts_purchased') != true) {
?>

<p><a href="https://www.paypal.com/cgi-bin/webscr?cmd=_xclick&business=info@domainsupport.co.uk&item_name=WP+Accounts+for+<?php echo (isset($_SERVER['HTTPS']) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST']; ?>&amount=30%2E00&currency_code=GBP" title="Upgrade WP Accounts">Upgrade now for &pound;30 to activate HTML download</a>.</p>

<p><a href="?page=export-csv&amp;activate=true" title="Activate WP Accounts Upgrade">Activate WP Accounts Upgrade</a>.</p>

<?php
	}
?>

<p><strong>Upgrade Status:</strong> <?php if (get_option('wp_accounts_purchased') == true) { echo('Upgraded'); } else { echo('Not Upgraded'); } ?></p>

<p>Use the button below to download this statement in HTML format.</p>
<form method="post" name="download_statement_form" action="<?php echo plugin_dir_url(__FILE__); ?>download-client-statement.php?id=<?= $client_id; ?>">

<?php wp_nonce_field('wpaccounts'); ?>

<p class="submit"><input type="submit" name="Submit" value="Download Statement"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> /></p>
</form>
</div>

<?php
}

function wpa_export_csv_options(){
    $this->wpa_export_csv();
}

function wpa_export_csv() {

    $options = get_option('wp_accounts_options');

	if (isset($_GET['activate']) && $_GET['activate'] == 'true') {
		$this->wpa_activate();
	}

?>
<div class="wrap">
<h2>Export Accounts</h2>

<?php
	if (get_option('wp_accounts_purchased') != true) {
?>

<p><a href="https://www.paypal.com/cgi-bin/webscr?cmd=_xclick&business=info@domainsupport.co.uk&item_name=WP+Accounts+for+<?php echo (isset($_SERVER['HTTPS']) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST']; ?>&amount=30%2E00&currency_code=GBP" title="Upgrade WP Accounts">Upgrade now for &pound;30 to activate CSV export</a>.</p>

<p><a href="?page=export-csv&amp;activate=true" title="Activate WP Accounts Upgrade">Activate WP Accounts Upgrade</a>.</p>

<?php
	}
?>

<p><strong>Upgrade Status:</strong> <?php if (get_option('wp_accounts_purchased') == true) { echo('Upgraded'); } else { echo('Not Upgraded'); } ?></p>

<p>Use the buttons below to export last year's accounts in CSV format.</p>
<form method="post" name="export_raised_form" action="<?php echo plugin_dir_url(__FILE__); ?>export-invoices-raised.php">

<?php wp_nonce_field('wpaccounts'); ?>

<p class="submit"><input type="submit" name="Submit" value="Export Invoices Raised"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> /></p>
</form>
<form method="post" name="export_paid_form" action="<?php echo plugin_dir_url(__FILE__); ?>export-invoices-paid.php">

<?php wp_nonce_field('wpaccounts'); ?>

<p class="submit"><input type="submit" name="Submit" value="Export Invoices Paid"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> /></p>
</form>
<form method="post" name="export_payments_form" action="<?php echo plugin_dir_url(__FILE__); ?>export-payments.php">

<?php wp_nonce_field('wpaccounts'); ?>

<p class="submit"><input type="submit" name="Submit" value="Export Payments"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> /></p>
</form>

<?php
    if ($options['mileage'] == 'true') {
?>

<form method="post" name="export_payments_form" action="<?php echo plugin_dir_url(__FILE__); ?>export-mileage.php">

<?php wp_nonce_field('wpaccounts'); ?>

<p class="submit"><input type="submit" name="Submit" value="Export Mileage"<?php if (get_option('wp_accounts_purchased') != true) { echo(' disabled'); } ?> /></p>
</form>

<?php
	}
?>

</div>
<?php
}

function wpa_activate() {

    $http_url = 'https://webd.uk/wp-accounts-activate/';
    $http_args = array(
        'timeout' => 15,
        'body' => array(
            'url' => ((isset($_SERVER['HTTPS']) ? "https" : "http") . '://' . $_SERVER['HTTP_HOST'])
        )
    );
    $request = wp_remote_post( $http_url, $http_args );

    if (is_wp_error($request)) {

        echo '<div class="notice notice-error"><p>Sorry, something\'s gone wrong. This often happens when the webd.uk server has been blocked by your hosting provider.</p></div>';

    } elseif (isset($request['body']) && $request['body'] == 'True') {

        update_option('wp_accounts_purchased', true);

    } else {

        delete_option('wp_accounts_purchased');

    }

}

function wpa_send_invoice($id, $send_copy = false) {
    global $wpdb;

    $invoice_attachments = array();

    $invoice = $wpdb->get_row($wpdb->prepare("SELECT " . $wpdb->prefix . "accounts_invoices.ID, " . $wpdb->prefix . "accounts_clients.contact, " . $wpdb->prefix . "accounts_clients.company, " . $wpdb->prefix . "accounts_clients.address1, " . $wpdb->prefix . "accounts_clients.address2, " . $wpdb->prefix . "accounts_clients.address3, " . $wpdb->prefix . "accounts_clients.town, " . $wpdb->prefix . "accounts_clients.county, " . $wpdb->prefix . "accounts_clients.postcode, " . $wpdb->prefix . "accounts_clients.email, " . $wpdb->prefix . "accounts_invoices.invoice_date, " . $wpdb->prefix . "accounts_invoices.item1, " . $wpdb->prefix . "accounts_invoices.item2, " . $wpdb->prefix . "accounts_invoices.item3, " . $wpdb->prefix . "accounts_invoices.item4, " . $wpdb->prefix . "accounts_invoices.item5, " . $wpdb->prefix . "accounts_invoices.price1, " . $wpdb->prefix . "accounts_invoices.price2, " . $wpdb->prefix . "accounts_invoices.price3, " . $wpdb->prefix . "accounts_invoices.price4, " . $wpdb->prefix . "accounts_invoices.price5, " . $wpdb->prefix . "accounts_invoices.date_paid, " . $wpdb->prefix . "accounts_invoice_status.status, " . $wpdb->prefix . "accounts_payment_methods.payment_method FROM " . $wpdb->prefix . "accounts_invoices INNER JOIN " . $wpdb->prefix . "accounts_clients ON " . $wpdb->prefix . "accounts_invoices.client = " . $wpdb->prefix . "accounts_clients.ID INNER JOIN " . $wpdb->prefix . "accounts_invoice_status ON " . $wpdb->prefix . "accounts_invoices.invoice_status = " . $wpdb->prefix . "accounts_invoice_status.ID LEFT JOIN " . $wpdb->prefix . "accounts_payment_methods ON " . $wpdb->prefix . "accounts_invoices.payment_method = " . $wpdb->prefix . "accounts_payment_methods.ID WHERE " . $wpdb->prefix . "accounts_invoices.ID = %d;",$id));
    if ($invoice) {

      if (empty($invoice->email) || $send_copy == true) {

        $current_user = wp_get_current_user();

        $invoice_to = $current_user->user_email;
      } else {
        $invoice_to = $invoice->email;
      }

$days_late = floor((strtotime(Date("Y-m-d")) - strtotime($invoice->invoice_date)) / 86400);

if ($invoice->status == 'Paid') {
  $invoice_subject = 'Receipt ' . $invoice->ID . ' from ' . get_bloginfo('name');
} elseif ($days_late > 90) {
  $invoice_subject = 'FOR YOUR IMMEDIATE ATTENTION';
} elseif ($days_late > 30) {
  $invoice_subject = 'Overdue Invoice ' . $invoice->ID . ' from ' . get_bloginfo('name');
} else {
  $invoice_subject = 'Invoice ' . $invoice->ID . ' from ' . get_bloginfo('name');
}

$invoice_body = file_get_contents(plugin_dir_path(__FILE__) . 'email-header.inc');

$options = get_option('wp_accounts_options');

if ($invoice->status == 'Paid') {
  $invoice_body = str_replace("!*type*!", 'Receipt', $invoice_body);
} elseif ($days_late > 30) {
  $invoice_body = str_replace("!*type*!", 'Overdue Invoice', $invoice_body);
} else {
  $invoice_body = str_replace("!*type*!", 'Invoice', $invoice_body);
}

$invoice_body = str_replace("!*invoice*!", $invoice->ID, $invoice_body);
$invoice_body = str_replace("!*company*!", get_bloginfo('name'), $invoice_body);
$invoice_body = str_replace("!*email_font*!", $options['email_font'], $invoice_body);
$invoice_body = str_replace("!*email_color*!", $options['email_color'], $invoice_body);
$invoice_body = str_replace("!*link_color*!", $options['link_color'], $invoice_body);
$invoice_body = str_replace("!*hover_color*!", $options['hover_color'], $invoice_body);

if ($invoice->status == 'Unpaid' && $days_late > 90) {

    $invoice_body .= '<p style="color: red; font-weight: bold;">The invoice below is now more than 90 days overdue. Please make payment now or contact us to make other financial arrangements. Thank you.</p>' . "\r\n";

} elseif (($invoice->status == 'Paid' || $days_late <= 30) && isset($options['company_google_place_id']) && $options['company_google_place_id'] != '') {

    $invoice_body .= '<p>Thank you for using our services and feel free to reply to this email with any comments or concerns you have. If we did well, please take a moment to review us on <a href="https://search.google.com/local/writereview?placeid=' . $options['company_google_place_id'] . '" title="Google Review">Google My Business</a>!</p>' . "\r\n";

}

if (get_option('wp_accounts_purchased') == true && isset($options['company_logo'])) {

    $invoice_body .= '<h1><a href="' . home_url() . '" title="' . get_bloginfo('name') . '"><img src="' . basename(get_attached_file($options['company_logo'])) . '" title="' . get_bloginfo('name') . '" alt="' . get_bloginfo('name') . '" /></a></h1>' . "\r\n";
    array_push($invoice_attachments, get_attached_file($options['company_logo']));

} else {

    $invoice_body .= '<h1><a href="' . home_url() . '" title="' . get_bloginfo('name') . '">' . get_bloginfo('name') . '</a></h1>' . "\r\n";

}

$invoice_body .= '<p>' . $options['company_address']. '<br />Telephone: ' . $this->wpa_format_telephone($this->wpa_clean_telephone($options['company_telephone'])) . '</p>' . "\r\n";

if ($invoice->status == 'Paid') {
  $invoice_body .= '<h2>Receipt</h2>' . "\r\n";
} elseif ($days_late > 30) {
  $invoice_body .= '<h2><span style="color: red;">Overdue</span> Invoice</h2>' . "\r\n";
} else {
  $invoice_body .= '<h2>Invoice</h2>' . "\r\n";
}

$invoice_body .= '<p><strong>Invoice Date:</strong> ' . mysql2date('jS F Y', $invoice->invoice_date) . '</p>' . "\r\n";
$invoice_body .= '<p><strong>Invoice Number:</strong> ' . $invoice->ID . '</p>' . "\r\n";
$invoice_body .= '<p><strong>To:</strong></p>' . "\r\n";
$invoice_body .= '<p>' . $invoice->contact . '<br />' . "\r\n";
if ($invoice->company) { $invoice_body .= $invoice->company . '<br />' . "\r\n"; }
if ($invoice->address1) { $invoice_body .= $invoice->address1 . '<br />' . "\r\n"; }
if ($invoice->address2) { $invoice_body .= $invoice->address2 . '<br />' . "\r\n"; }
if ($invoice->address3) { $invoice_body .= $invoice->address3 . '<br />' . "\r\n"; }
$invoice_body .= $invoice->town . '<br />' . "\r\n";
if ($invoice->county) { $invoice_body .= $invoice->county . '<br />' . "\r\n"; }
$invoice_body .= $invoice->postcode . '</p>' . "\r\n";
$invoice_body .= '<table class="invoice" cellspacing=0>' . "\r\n" . '<tr><td><strong>Description:</strong></td><td><strong>Price:</strong></td></tr>' . "\r\n";
$invoice_body .= '<tr><td>' . $invoice->item1 . '</td><td>&pound;' . $invoice->price1 . '</td></tr>' . "\r\n";
if ($invoice->item2) { $invoice_body .= '<tr><td>' . $invoice->item2 . '</td><td>&pound;' . $invoice->price2 . '</td></tr>' . "\r\n"; }
if ($invoice->item3) { $invoice_body .= '<tr><td>' . $invoice->item3 . '</td><td>&pound;' . $invoice->price3 . '</td></tr>' . "\r\n"; }
if ($invoice->item4) { $invoice_body .= '<tr><td>' . $invoice->item4 . '</td><td>&pound;' . $invoice->price4 . '</td></tr>' . "\r\n"; }
if ($invoice->item5) { $invoice_body .= '<tr><td>' . $invoice->item5 . '</td><td>&pound;' . $invoice->price5 . '</td></tr>' . "\r\n"; }
$invoice_body .= '<tr><td><strong>Total:</strong></td><td><strong>&pound;' . number_format(($invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5),2) . '</strong></td></tr>' . "\r\n" . '</table>' . "\r\n";

if ($invoice->status != 'Paid') {
$invoice_body .= '<p><strong>To pay by BACS</strong>, use sort code <strong>' . $options['sort_code'] . '</strong> and account number <strong>' . $options['account_number']. '</strong>, using reference <strong>' . substr($invoice->ID . '-' . strtoupper(preg_replace('/[^a-zA-Z"\']/', '', $invoice->contact)),0,18) . '</strong> where possible. Please remember to send remittance advice so we know to look out for your payment.</p>' . "\r\n";

if (isset($options['cheques']) && $options['cheques'] == 'true') {

$invoice_body .= '<p><strong>To pay by Cheque</strong>, make your cheque payable to <strong>' . $options['company_name']. '</strong>, ' . $options['company_address']. '.</p>' . "\r\n";

} else {

$invoice_body .= '<p><strong>We regret that we can no longer accept payments by Cheque</strong>.' . "\r\n";
   
}

if (isset($options['paypal']) && $options['paypal'] == 'true') {

$invoice_body .= '<p><strong>To pay by Credit Card, Debit Card or Paypal</strong>, <a href="https://www.paypal.com/cgi-bin/webscr?cmd=_xclick&business=' . get_bloginfo('admin_email') . '&item_name=' . get_bloginfo('name') . ' Invoice No. ' . $invoice->ID . '&item_number=' . $invoice->ID . '&amount=' . urlencode(number_format(($invoice->price1 + $invoice->price2 + $invoice->price3 + $invoice->price4 + $invoice->price5),2)) . '&currency_code=GBP" title="Pay now by Credit Card, Debit Card or Paypal">follow this link</a>.</p>' . "\r\n";

}

$invoice_body .= '<p>Please settle this account within 30 days of the invoice date.</p>' . "\r\n";
} elseif ($invoice->status = 'Paid') {
$invoice_body .= '<p>Payment received with thanks on ' . mysql2date('jS F Y', $invoice->date_paid) . ' by ' . $invoice->payment_method . '.</p>' . "\r\n";
}

if (get_option('wp_accounts_purchased') == true && isset($options['email_advert'])) {

    $invoice_body .= '<p><img src="' . basename(get_attached_file($options['email_advert'])) . '" /></p>' . "\r\n";
    array_push($invoice_attachments, get_attached_file($options['email_advert']));

}

$invoice_body .= file_get_contents(plugin_dir_path(__FILE__) . 'email-footer.inc');

$invoice_body = str_replace("!*email_footer*!", apply_filters('the_content', $options['email_footer']), $invoice_body);

$invoice_headers = 'From: ' . get_bloginfo('name') . ' <' . get_bloginfo('admin_email') . '>' . "\r\n";

if ($invoice->status == 'Unpaid' && $days_late > 30) {
  $invoice_headers .= "X-Priority: 1 (Highest)\r\n";
  $invoice_headers .= "X-MSMail-Priority: High\r\n";
  $invoice_headers .= "Importance: High\r\n";
}

add_filter('wp_mail_content_type', array($this, 'wpa_set_html_content_type'));
wp_mail($invoice_to, $invoice_subject, $invoice_body, $invoice_headers, $invoice_attachments);
remove_filter('wp_mail_content_type', array($this, 'wpa_set_html_content_type'));
?>

<p>Invoice sent to <strong><?php echo $invoice_to; ?></strong>.</p>

<?php
    }
}

function wpa_set_html_content_type() {
	return 'text/html';
}

function wpa_manage_payments_options(){
    $this->wpa_payments_action();
    if (empty($_GET['edit'])) {
        $this->wpa_manage_payments();
    } else {
        $this->wpa_add_payment();   
    }
}

function wpa_payments_action(){
    global $wpdb;

    if(current_user_can('manage_options') && isset($_GET['delete'])) {

		check_admin_referer('wpaccounts');

        $payment_id = absint($_GET['delete']);
        $wpdb->query($wpdb->prepare("DELETE FROM " . $wpdb->prefix . "accounts_payments WHERE ID=%d;",$payment_id));
    }

    if(current_user_can('manage_options') && isset($_POST['accounts_add_payment']) and isset($_POST['accounts_payments_supplier']) and isset($_POST['accounts_payments_invoice_date']) and isset($_POST['accounts_payments_amount']) and isset($_POST['accounts_payments_expense_type']) and isset($_POST['accounts_payments_date_paid']) and isset($_POST['accounts_payments_payment_method']) ) {

		check_admin_referer('wpaccounts');

		$_POST = array_map( 'stripslashes_deep', $_POST);

        $supplier = empty($_POST['accounts_payments_supplier']) ? NULL : sanitize_text_field($_POST['accounts_payments_supplier']);
        $invoice_date = (strtotime(sanitize_text_field($_POST['accounts_payments_invoice_date'])) && !empty($_POST['accounts_payments_invoice_date'])) ? sanitize_text_field($_POST['accounts_payments_invoice_date']) : NULL;
        $amount = (is_numeric($_POST['accounts_payments_amount']) && !empty($_POST['accounts_payments_amount'])) ? $_POST['accounts_payments_amount'] : NULL;
        $reference = empty($_POST['accounts_payments_reference']) ? NULL : sanitize_text_field($_POST['accounts_payments_reference']);
        $expense_type = (is_numeric($_POST['accounts_payments_expense_type']) && !empty($_POST['accounts_payments_expense_type'])) ? $_POST['accounts_payments_expense_type'] : NULL;
        $date_paid = (strtotime(sanitize_text_field($_POST['accounts_payments_date_paid'])) && !empty($_POST['accounts_payments_date_paid'])) ? sanitize_text_field($_POST['accounts_payments_date_paid']) : NULL;
        $payment_method = (is_numeric($_POST['accounts_payments_payment_method']) && !empty($_POST['accounts_payments_payment_method'])) ? $_POST['accounts_payments_payment_method'] : NULL;
        $notes = empty($_POST['accounts_payments_notes']) ? NULL : sanitize_text_field($_POST['accounts_payments_notes']);
        $mileage = (isset($_POST['accounts_payments_mileage']) && is_numeric($_POST['accounts_payments_mileage'])) ? $_POST['accounts_payments_mileage'] : NULL;

        if(empty($_POST['accounts_payments_id'])) {
            if ($wpdb->insert(
	        $wpdb->prefix . 'accounts_payments',
	            array(
		        'supplier' => $supplier,
		        'invoice_date' => $invoice_date,
		        'amount' => $amount,
	        	'reference' => $reference,
	        	'expense_type' => $expense_type,
	        	'date_paid' => $date_paid,
	        	'payment_method' => $payment_method,
	        	'notes' => $notes,
	        	'mileage' => $mileage
	            ), 
	            array(
	        	'%s',
	        	'%s',
	        	'%f',
	        	'%s',
	        	'%d',
	        	'%s',
	        	'%d',
	        	'%s',
				'%d'
	            )
            ) != false) {
                echo '<p style="color: green;">Payment Insert Success</p>';
            } else {
                echo '<p style="color: red; font-size: 2em;">Payment Insert Fail</p>';
echo $wpdb->last_error;
            }
        } elseif (is_numeric($_POST['accounts_payments_id'])) {
            if ($wpdb->update(
	        $wpdb->prefix . 'accounts_payments',
	            array(
		        'supplier' => $supplier,
		        'invoice_date' => $invoice_date,
		        'amount' => $amount,
	        	'reference' => $reference,
	        	'expense_type' => $expense_type,
	        	'date_paid' => $date_paid,
	        	'payment_method' => $payment_method,
	        	'notes' => $notes,
	        	'mileage' => $mileage
	            ),
	            array( 'ID' => $_POST['accounts_payments_id'] ),
	            array(
	        	'%s',
	        	'%s',
	        	'%f',
	        	'%s',
	        	'%d',
	        	'%s',
	        	'%d',
	        	'%s',
				'%d'
	            ), 
	            array( '%d' )
            ) != false) {
                echo '<p style="color: green;">Payment Update Success</p>';
            } else {
                echo '<p style="color: red; font-size: 2em;">Payment Update Fail</p>';
echo $wpdb->last_error;
            }
        }
    }  
}

function wpa_add_payment() {

    $payment_id = 0;
    if(isset($_GET['id']) && !isset($_GET['copy'])) { $payment_id = absint($_GET['id']); }

    global $edit_payments;
    if (isset($_GET['id'])) $edit_payments = $this->wpa_accounts_get_row(absint($_GET['id']),'accounts_payments');   

    add_meta_box('accounts-meta', __('Payment Details'), array($this, 'wpa_payment_meta_box'), 'accounts-payments', 'normal', 'core' );
?>

    <div class="wrap">
      <div id="faq-wrapper">
        <form method="post" action="?page=manage-payments">

<?php wp_nonce_field('wpaccounts'); ?>

          <h2>
          <?php if ($payment_id == 0) {
                $tf_title = __('Add Payment');
          }else {
                $tf_title = __('Edit Payment') . ' ' . $payment_id;
          }
          echo $tf_title;
          ?>
          </h2>
          <div id="poststuff" class="metabox-holder">
            <?php do_meta_boxes('accounts-payments', 'normal','low'); ?>
          </div>
          <input type="hidden" name="accounts_payments_id" value="<?php echo $payment_id; ?>" />
          <input type="submit" value="<?php echo $tf_title;?>" name="accounts_add_payment" id="accounts_add_payment" class="button-secondary">
        </form>
      </div>
    </div>
<?php
}

function wpa_manage_payments() {
?>
<div class="wrap">
  <div class="icon32" id="icon-edit"><br></div>
  <h2><?php _e('Manage Payments') ?></h2>
  <form method="post" action="?page=manage-payments" id="accounts_form_action">

<?php wp_nonce_field('wpaccounts'); ?>

    <p>
        <select name="accounts_payments_action">
            <option value="actions"><?php _e('Actions')?></option>
            <!--<option value="delete"><?php _e('Delete')?></option>-->
      </select>
      <input type="submit" name="accounts_form_action_changes" class="button-secondary" value="<?php _e('Apply')?>" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Payment')?>" onclick="window.location='?page=manage-payments&amp;edit=true'" />
    </p>
    <table class="widefat page fixed" cellpadding="0">
      <thead>
        <tr>
        <th id="cb" class="manage-column column-cb check-column" style="" scope="col">
          <input type="checkbox"/>
        </th>
          <th class="manage-column"><?php _e('ID / Payment Method')?></th>
          <th class="manage-column"><?php _e('Supplier')?></th>
          <th class="manage-column"><?php _e('Date')?></th>
          <th class="manage-column"><?php _e('Amount')?></th>
        </tr>
      </thead>
      <tfoot>
        <tr>
        <th id="cb" class="manage-column column-cb check-column" style="" scope="col">
          <input type="checkbox"/>
        </th>
          <th class="manage-column"><?php _e('ID / Payment Method')?></th>
          <th class="manage-column"><?php _e('Supplier')?></th>
          <th class="manage-column"><?php _e('Date')?></th>
          <th class="manage-column"><?php _e('Amount')?></th>
        </tr>
      </tfoot>
      <tbody>
        <?php
          $payments = $this->wpa_accounts_get_data('accounts_payments', false);
          if($payments){
           $i=0;
           foreach($payments as $payment) { 
               $i++;
        ?>
      <tr class="<?php echo (ceil($i/2) == ($i/2)) ? "" : "alternate"; ?>">
        <th class="check-column" scope="row">
          <input type="checkbox" value="<?php echo $payment->ID; ?>" name="payment_id[]" />
        </th>
          <td>
          <strong><?php echo $payment->ID; ?></strong> - <?php echo $payment->payment_method; ?>
          <div class="row-actions-visible">
          <span class="edit"><a href="?page=manage-payments&amp;id=<?php echo $payment->ID; ?>&amp;edit=true">Edit</a> | </span>
          <span class="edit"><a href="?page=manage-payments&amp;id=<?php echo $payment->ID; ?>&amp;edit=true&amp;copy=true">Copy</a></span>
          <!--<span class="delete"><a href="?page=manage-payments&amp;delete=<?php echo $payment->ID; ?>" onclick="return confirm('Are you sure you want to delete this payment?');">Delete</a></span>-->
          </div>
          </td>
          <td><?php echo $payment->supplier; ?></td>
          <td>Invoice Date: <?php echo date('jS F Y',strtotime($payment->invoice_date)); ?><br />
          Date Paid: <?php echo date('jS F Y',strtotime($payment->date_paid)); ?></td>
          <td>&pound;<?php echo number_format($payment->amount,2); ?></td>
        </tr>
        <?php
           }
        }
        else{   
      ?>
        <tr><td colspan="4"><?php _e('There are no payments.')?></td></tr>   
        <?php
      }
        ?>   
      </tbody>
    </table>
    <p>
        <select name="accounts_payments_action-2">
            <option value="actions"><?php _e('Actions')?></option>
            <!--<option value="delete"><?php _e('Delete')?></option>-->
        </select>
        <input type="submit" name="accounts_form_action_changes-2" class="button-secondary" value="<?php _e('Apply')?>" />
        <input type="button" class="button-secondary" value="<?php _e('Add a new Payment')?>" onclick="window.location='?page=manage-payments&amp;edit=true'" />
    </p>

  </form>
</div>
<?php
}



        function wpa_clean_telephone($telephone) {

        	$clean_telephone = '';

        	if (strlen($telephone) > 0) {

        		for ($i=0; $i<strlen($telephone); $i++) {

        			if ($i == 0 && substr($telephone, $i, 1) == '+') {

        				$clean_telephone = '00';

        			}

        			if (strpos('0123456789', substr($telephone, $i, 1)) !== false) {

        				$clean_telephone .= substr($telephone, $i, 1);

        			}

        		}

        	}

        	if (strlen($clean_telephone) > 5) {

        		if (substr($clean_telephone, 0, 5) == '00440') {

        			$clean_telephone = '0' . substr($clean_telephone, 5);

        		}

        	}

        	if (strlen($clean_telephone) > 4) {

        		if (substr($clean_telephone, 0, 4) == '0044') {

        			$clean_telephone = '0' . substr($clean_telephone, 4);

        		}

        	}

        	return $clean_telephone;

        }

        function wpa_format_telephone($telephone) {

        	if (strlen($telephone)>8) {

        		if (substr($telephone,0,2) == '01' || (substr($telephone,0,2) == '07' && substr($telephone,0,3) <> '070')) {

        			$telephone = substr($telephone,0,5).' '.substr($telephone,5,3).' '.substr($telephone,8);

        		} elseif (substr($telephone,0,2) == '02' || substr($telephone,0,3) == '055' || substr($telephone,0,3) == '056' || substr($telephone,0,3) == '070') {

        			$telephone = substr($telephone,0,3).' '.substr($telephone,3,4).' '.substr($telephone,7);

        		} elseif (substr($telephone,0,2) == '03' || substr($telephone,0,3) == '050' || substr($telephone,0,2) == '08' || substr($telephone,0,2) == '09') {

        			$telephone = substr($telephone,0,4).' '.substr($telephone,4,3).' '.substr($telephone,7);

        		}

        	}

        	if (strlen($telephone)>2) {

        		if (substr($telephone,0,2) == '00') {

        			$telephone = '+'.substr($telephone,3);

        		}

        	}

        	return $telephone;

        }

		function wpa_home_root() {

			$home_root = parse_url(home_url());

			if (isset($home_root['path'])) {

				$home_root = trailingslashit($home_root['path']);

			} else {

				$home_root = '/';

			}

			return $home_root;

		}

	}

	$WPAccounts_Object = new wpaccounts_class();

}

?>
